# 
# Generated by the nebius.base.protos.compiler.  DO NOT EDIT!
# 

"""Auto-generated Nebius SDK package for ``nebius.logging.agentmanager.v1``"""

import builtins as builtins
import collections.abc as abc
import datetime as datetime
import google.protobuf.descriptor as descriptor_1
import google.protobuf.duration_pb2 as duration_pb2
import google.protobuf.message as message
import nebius.aio.client as client
import nebius.aio.request as request
import nebius.aio.request_kwargs as request_kwargs
import nebius.api.nebius.logging.v1.agentmanager.version_service_pb2 as version_service_pb2
import nebius.base.protos.descriptor as descriptor
import nebius.base.protos.pb_classes as pb_classes
import nebius.base.protos.pb_enum as pb_enum
import nebius.base.protos.unset as unset
import nebius.base.protos.well_known as well_known
import typing as typing
import typing_extensions as typing_extensions
#@ local imports here @#

# file: nebius/logging/v1/agentmanager/version_service.proto
class AgentType(pb_enum.Enum):
    """
    Type of the agent in the system.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.logging.agentmanager.v1.AgentType",version_service_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
    AGENT_UNDEFINED = 0
    """
    Default undefined state.
    """
    
    O11Y_AGENT = 1
    """
    Observability agent type.
    """
    

class AgentState(pb_enum.Enum):
    """
    Current operational state of the agent.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.logging.agentmanager.v1.AgentState",version_service_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
    STATE_UNDEFINED = 0
    """
    Default undefined state.
    """
    
    STATE_HEALTHY = 1
    """
    Agent is functioning normally.
    """
    
    STATE_ERROR = 2
    """
    Agent is in error state.
    """
    

class Action(pb_enum.Enum):
    """
    Action to be taken by the agent based on version check.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.logging.agentmanager.v1.Action",version_service_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
    ACTION_UNDEFINED = 0
    """
    Default undefined action.
    """
    
    NOP = 1
    """
    No operation needed.
    """
    
    UPDATE = 2
    """
    Update to new version required.
    """
    
    RESTART = 3
    """
    Agent restart required.
    """
    

class GetVersionRequest(pb_classes.Message):
    """
    Request message for GetVersion RPC containing agent status and system information.
    """
    
    __PB2_CLASS__ = version_service_pb2.GetVersionRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.logging.agentmanager.v1.GetVersionRequest",version_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
        "agent_uptime": well_known.duration_mask,
        "system_uptime": well_known.duration_mask,
        "updater_uptime": well_known.duration_mask,
    }
    
    def __init__(
        self,
        initial_message: message.Message|None = None,
        *,
        type: "AgentType|version_service_pb2.AgentType|None|unset.UnsetType" = unset.Unset,
        agent_version: "builtins.str|None|unset.UnsetType" = unset.Unset,
        updater_version: "builtins.str|None|unset.UnsetType" = unset.Unset,
        parent_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        instance_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        os_info: "OSInfo|version_service_pb2.OSInfo|None|unset.UnsetType" = unset.Unset,
        agent_state: "AgentState|version_service_pb2.AgentState|None|unset.UnsetType" = unset.Unset,
        agent_uptime: "duration_pb2.Duration|datetime.timedelta|None|unset.UnsetType" = unset.Unset,
        system_uptime: "duration_pb2.Duration|datetime.timedelta|None|unset.UnsetType" = unset.Unset,
        updater_uptime: "duration_pb2.Duration|datetime.timedelta|None|unset.UnsetType" = unset.Unset,
        agent_state_messages: "abc.Iterable[builtins.str]|None|unset.UnsetType" = unset.Unset,
        last_update_error: "builtins.str|None|unset.UnsetType" = unset.Unset,
        mk8s_cluster_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        modules_health: "ModulesHealth|version_service_pb2.ModulesHealth|None|unset.UnsetType" = unset.Unset,
        cloud_init_status: "builtins.str|None|unset.UnsetType" = unset.Unset,
        instance_id_used_fallback: "builtins.bool|None|unset.UnsetType" = unset.Unset,
        last_agent_logs: "builtins.str|None|unset.UnsetType" = unset.Unset,
        gpu_model: "builtins.str|None|unset.UnsetType" = unset.Unset,
        gpu_number: "builtins.int|None|unset.UnsetType" = unset.Unset,
        dcgm_version: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(type, unset.UnsetType):
            self.type = type
        if not isinstance(agent_version, unset.UnsetType):
            self.agent_version = agent_version
        if not isinstance(updater_version, unset.UnsetType):
            self.updater_version = updater_version
        if not isinstance(parent_id, unset.UnsetType):
            self.parent_id = parent_id
        if not isinstance(instance_id, unset.UnsetType):
            self.instance_id = instance_id
        if not isinstance(os_info, unset.UnsetType):
            self.os_info = os_info
        if not isinstance(agent_state, unset.UnsetType):
            self.agent_state = agent_state
        if not isinstance(agent_uptime, unset.UnsetType):
            self.agent_uptime = agent_uptime
        if not isinstance(system_uptime, unset.UnsetType):
            self.system_uptime = system_uptime
        if not isinstance(updater_uptime, unset.UnsetType):
            self.updater_uptime = updater_uptime
        if not isinstance(agent_state_messages, unset.UnsetType):
            self.agent_state_messages = agent_state_messages
        if not isinstance(last_update_error, unset.UnsetType):
            self.last_update_error = last_update_error
        if not isinstance(mk8s_cluster_id, unset.UnsetType):
            self.mk8s_cluster_id = mk8s_cluster_id
        if not isinstance(modules_health, unset.UnsetType):
            self.modules_health = modules_health
        if not isinstance(cloud_init_status, unset.UnsetType):
            self.cloud_init_status = cloud_init_status
        if not isinstance(instance_id_used_fallback, unset.UnsetType):
            self.instance_id_used_fallback = instance_id_used_fallback
        if not isinstance(last_agent_logs, unset.UnsetType):
            self.last_agent_logs = last_agent_logs
        if not isinstance(gpu_model, unset.UnsetType):
            self.gpu_model = gpu_model
        if not isinstance(gpu_number, unset.UnsetType):
            self.gpu_number = gpu_number
        if not isinstance(dcgm_version, unset.UnsetType):
            self.dcgm_version = dcgm_version
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "type",
            "agent_version",
            "updater_version",
            "parent_id",
            "instance_id",
            "os_info",
            "agent_state",
            "agent_uptime",
            "system_uptime",
            "updater_uptime",
            "agent_state_messages",
            "last_update_error",
            "mk8s_cluster_id",
            "modules_health",
            "cloud_init_status",
            "instance_id_used_fallback",
            "last_agent_logs",
            "gpu_model",
            "gpu_number",
            "dcgm_version",
        ]
    
    @builtins.property
    def type(self) -> "AgentType":
        """
        Type of the agent. Must be O11Y_AGENT (1).
        """
        
        return super()._get_field("type", explicit_presence=False,
        wrap=AgentType,
        )
    @type.setter
    def type(self, value: "AgentType|version_service_pb2.AgentType|None") -> None:
        return super()._set_field("type",value,explicit_presence=False,
        )
    
    @builtins.property
    def agent_version(self) -> "builtins.str":
        """
        Current version of the agent software.
        """
        
        return super()._get_field("agent_version", explicit_presence=False,
        )
    @agent_version.setter
    def agent_version(self, value: "builtins.str|None") -> None:
        return super()._set_field("agent_version",value,explicit_presence=False,
        )
    
    @builtins.property
    def updater_version(self) -> "builtins.str":
        """
        Version of the updater component.
        """
        
        return super()._get_field("updater_version", explicit_presence=False,
        )
    @updater_version.setter
    def updater_version(self, value: "builtins.str|None") -> None:
        return super()._set_field("updater_version",value,explicit_presence=False,
        )
    
    @builtins.property
    def parent_id(self) -> "builtins.str":
        """
        Parent identifier for the VM
        """
        
        return super()._get_field("parent_id", explicit_presence=False,
        )
    @parent_id.setter
    def parent_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("parent_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def instance_id(self) -> "builtins.str":
        """
        Unique identifier for the instance where agent is running.
        """
        
        return super()._get_field("instance_id", explicit_presence=False,
        )
    @instance_id.setter
    def instance_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("instance_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def os_info(self) -> "OSInfo":
        """
        Detailed information about the operating system.
        """
        
        return super()._get_field("os_info", explicit_presence=False,
        wrap=OSInfo,
        )
    @os_info.setter
    def os_info(self, value: "OSInfo|version_service_pb2.OSInfo|None") -> None:
        return super()._set_field("os_info",value,explicit_presence=False,
        )
    
    @builtins.property
    def agent_state(self) -> "AgentState":
        """
        Current operational state of the agent.
        """
        
        return super()._get_field("agent_state", explicit_presence=False,
        wrap=AgentState,
        )
    @agent_state.setter
    def agent_state(self, value: "AgentState|version_service_pb2.AgentState|None") -> None:
        return super()._set_field("agent_state",value,explicit_presence=False,
        )
    
    @builtins.property
    def agent_uptime(self) -> "datetime.timedelta":
        """
        Time duration since the agent started.
        """
        
        return super()._get_field("agent_uptime", explicit_presence=False,
        wrap=well_known.from_duration
        )
    @agent_uptime.setter
    def agent_uptime(self, value: "duration_pb2.Duration|datetime.timedelta|None") -> None:
        return super()._set_field("agent_uptime",value,explicit_presence=False,
        unwrap=well_known.to_duration
        )
    
    @builtins.property
    def system_uptime(self) -> "datetime.timedelta":
        """
        Total system uptime.
        """
        
        return super()._get_field("system_uptime", explicit_presence=False,
        wrap=well_known.from_duration
        )
    @system_uptime.setter
    def system_uptime(self, value: "duration_pb2.Duration|datetime.timedelta|None") -> None:
        return super()._set_field("system_uptime",value,explicit_presence=False,
        unwrap=well_known.to_duration
        )
    
    @builtins.property
    def updater_uptime(self) -> "datetime.timedelta":
        """
        Time duration since the updater component started.
        """
        
        return super()._get_field("updater_uptime", explicit_presence=False,
        wrap=well_known.from_duration
        )
    @updater_uptime.setter
    def updater_uptime(self, value: "duration_pb2.Duration|datetime.timedelta|None") -> None:
        return super()._set_field("updater_uptime",value,explicit_presence=False,
        unwrap=well_known.to_duration
        )
    
    @builtins.property
    def agent_state_messages(self) -> "abc.MutableSequence[builtins.str]":
        """
        Status messages from the agent describing its current state.
        """
        
        return super()._get_field("agent_state_messages", explicit_presence=False,
        wrap=pb_classes.Repeated,
        )
    @agent_state_messages.setter
    def agent_state_messages(self, value: "abc.Iterable[builtins.str]|None") -> None:
        return super()._set_field("agent_state_messages",value,explicit_presence=False,
        )
    
    @builtins.property
    def last_update_error(self) -> "builtins.str":
        """
        Description of the last update failure, if any.
        """
        
        return super()._get_field("last_update_error", explicit_presence=False,
        )
    @last_update_error.setter
    def last_update_error(self, value: "builtins.str|None") -> None:
        return super()._set_field("last_update_error",value,explicit_presence=False,
        )
    
    @builtins.property
    def mk8s_cluster_id(self) -> "builtins.str":
        """
        Managed Kubernetes cluster identifier, if applicable.
        """
        
        return super()._get_field("mk8s_cluster_id", explicit_presence=False,
        )
    @mk8s_cluster_id.setter
    def mk8s_cluster_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("mk8s_cluster_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def modules_health(self) -> "ModulesHealth":
        """
        Health status of individual agent modules.
        """
        
        return super()._get_field("modules_health", explicit_presence=False,
        wrap=ModulesHealth,
        )
    @modules_health.setter
    def modules_health(self, value: "ModulesHealth|version_service_pb2.ModulesHealth|None") -> None:
        return super()._set_field("modules_health",value,explicit_presence=False,
        )
    
    @builtins.property
    def cloud_init_status(self) -> "builtins.str":
        """
        Status of cloud initialization process.
        """
        
        return super()._get_field("cloud_init_status", explicit_presence=False,
        )
    @cloud_init_status.setter
    def cloud_init_status(self, value: "builtins.str|None") -> None:
        return super()._set_field("cloud_init_status",value,explicit_presence=False,
        )
    
    @builtins.property
    def instance_id_used_fallback(self) -> "builtins.bool":
        """
        Indicates if a fallback method was used to determine instance_id.
        """
        
        return super()._get_field("instance_id_used_fallback", explicit_presence=False,
        )
    @instance_id_used_fallback.setter
    def instance_id_used_fallback(self, value: "builtins.bool|None") -> None:
        return super()._set_field("instance_id_used_fallback",value,explicit_presence=False,
        )
    
    @builtins.property
    def last_agent_logs(self) -> "builtins.str":
        """
        Recent agent log entries for diagnostic purposes.
        """
        
        return super()._get_field("last_agent_logs", explicit_presence=False,
        )
    @last_agent_logs.setter
    def last_agent_logs(self, value: "builtins.str|None") -> None:
        return super()._set_field("last_agent_logs",value,explicit_presence=False,
        )
    
    @builtins.property
    def gpu_model(self) -> "builtins.str":
        """
        Model of the GPU used in the system.
        """
        
        return super()._get_field("gpu_model", explicit_presence=False,
        )
    @gpu_model.setter
    def gpu_model(self, value: "builtins.str|None") -> None:
        return super()._set_field("gpu_model",value,explicit_presence=False,
        )
    
    @builtins.property
    def gpu_number(self) -> "builtins.int":
        """
        Number of GPUs available in the system.
        """
        
        return super()._get_field("gpu_number", explicit_presence=False,
        )
    @gpu_number.setter
    def gpu_number(self, value: "builtins.int|None") -> None:
        return super()._set_field("gpu_number",value,explicit_presence=False,
        )
    
    @builtins.property
    def dcgm_version(self) -> "builtins.str":
        """
        Version of the DCGM (Data Center GPU Manager) used.
        """
        
        return super()._get_field("dcgm_version", explicit_presence=False,
        )
    @dcgm_version.setter
    def dcgm_version(self, value: "builtins.str|None") -> None:
        return super()._set_field("dcgm_version",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "type":"type",
        "agent_version":"agent_version",
        "updater_version":"updater_version",
        "parent_id":"parent_id",
        "instance_id":"instance_id",
        "os_info":"os_info",
        "agent_state":"agent_state",
        "agent_uptime":"agent_uptime",
        "system_uptime":"system_uptime",
        "updater_uptime":"updater_uptime",
        "agent_state_messages":"agent_state_messages",
        "last_update_error":"last_update_error",
        "mk8s_cluster_id":"mk8s_cluster_id",
        "modules_health":"modules_health",
        "cloud_init_status":"cloud_init_status",
        "instance_id_used_fallback":"instance_id_used_fallback",
        "last_agent_logs":"last_agent_logs",
        "gpu_model":"gpu_model",
        "gpu_number":"gpu_number",
        "dcgm_version":"dcgm_version",
    }
    
class ModulesHealth(pb_classes.Message):
    """
    Health status information for all agent modules.
    """
    
    __PB2_CLASS__ = version_service_pb2.ModulesHealth
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.logging.agentmanager.v1.ModulesHealth",version_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message.Message|None = None,
        *,
        process: "ModuleHealth|version_service_pb2.ModuleHealth|None|unset.UnsetType" = unset.Unset,
        gpu_pipeline: "ModuleHealth|version_service_pb2.ModuleHealth|None|unset.UnsetType" = unset.Unset,
        cpu_pipeline: "ModuleHealth|version_service_pb2.ModuleHealth|None|unset.UnsetType" = unset.Unset,
        cilium_pipeline: "ModuleHealth|version_service_pb2.ModuleHealth|None|unset.UnsetType" = unset.Unset,
        vmapps_pipeline: "ModuleHealth|version_service_pb2.ModuleHealth|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(process, unset.UnsetType):
            self.process = process
        if not isinstance(gpu_pipeline, unset.UnsetType):
            self.gpu_pipeline = gpu_pipeline
        if not isinstance(cpu_pipeline, unset.UnsetType):
            self.cpu_pipeline = cpu_pipeline
        if not isinstance(cilium_pipeline, unset.UnsetType):
            self.cilium_pipeline = cilium_pipeline
        if not isinstance(vmapps_pipeline, unset.UnsetType):
            self.vmapps_pipeline = vmapps_pipeline
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "process",
            "gpu_pipeline",
            "cpu_pipeline",
            "cilium_pipeline",
            "vmapps_pipeline",
        ]
    
    @builtins.property
    def process(self) -> "ModuleHealth":
        """
        Health status of the process module.
        """
        
        return super()._get_field("process", explicit_presence=False,
        wrap=ModuleHealth,
        )
    @process.setter
    def process(self, value: "ModuleHealth|version_service_pb2.ModuleHealth|None") -> None:
        return super()._set_field("process",value,explicit_presence=False,
        )
    
    @builtins.property
    def gpu_pipeline(self) -> "ModuleHealth":
        """
        Health status of the GPU pipeline module.
        """
        
        return super()._get_field("gpu_pipeline", explicit_presence=False,
        wrap=ModuleHealth,
        )
    @gpu_pipeline.setter
    def gpu_pipeline(self, value: "ModuleHealth|version_service_pb2.ModuleHealth|None") -> None:
        return super()._set_field("gpu_pipeline",value,explicit_presence=False,
        )
    
    @builtins.property
    def cpu_pipeline(self) -> "ModuleHealth":
        """
        Health status of the CPU pipeline module.
        """
        
        return super()._get_field("cpu_pipeline", explicit_presence=False,
        wrap=ModuleHealth,
        )
    @cpu_pipeline.setter
    def cpu_pipeline(self, value: "ModuleHealth|version_service_pb2.ModuleHealth|None") -> None:
        return super()._set_field("cpu_pipeline",value,explicit_presence=False,
        )
    
    @builtins.property
    def cilium_pipeline(self) -> "ModuleHealth":
        """
        Health status of the Cilium pipeline module.
        """
        
        return super()._get_field("cilium_pipeline", explicit_presence=False,
        wrap=ModuleHealth,
        )
    @cilium_pipeline.setter
    def cilium_pipeline(self, value: "ModuleHealth|version_service_pb2.ModuleHealth|None") -> None:
        return super()._set_field("cilium_pipeline",value,explicit_presence=False,
        )
    
    @builtins.property
    def vmapps_pipeline(self) -> "ModuleHealth":
        """
        Health status of the VM applications pipeline module.
        """
        
        return super()._get_field("vmapps_pipeline", explicit_presence=False,
        wrap=ModuleHealth,
        )
    @vmapps_pipeline.setter
    def vmapps_pipeline(self, value: "ModuleHealth|version_service_pb2.ModuleHealth|None") -> None:
        return super()._set_field("vmapps_pipeline",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "process":"process",
        "gpu_pipeline":"gpu_pipeline",
        "cpu_pipeline":"cpu_pipeline",
        "cilium_pipeline":"cilium_pipeline",
        "vmapps_pipeline":"vmapps_pipeline",
    }
    
class ModuleHealth(pb_classes.Message):
    """
    Health status information for an individual module.
    """
    
    __PB2_CLASS__ = version_service_pb2.ModuleHealth
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.logging.agentmanager.v1.ModuleHealth",version_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message.Message|None = None,
        *,
        state: "AgentState|version_service_pb2.AgentState|None|unset.UnsetType" = unset.Unset,
        messages: "abc.Iterable[builtins.str]|None|unset.UnsetType" = unset.Unset,
        parameters: "abc.Iterable[Parameter]|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(state, unset.UnsetType):
            self.state = state
        if not isinstance(messages, unset.UnsetType):
            self.messages = messages
        if not isinstance(parameters, unset.UnsetType):
            self.parameters = parameters
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "state",
            "messages",
            "parameters",
        ]
    
    @builtins.property
    def state(self) -> "AgentState":
        """
        Current operational state of the module.
        """
        
        return super()._get_field("state", explicit_presence=False,
        wrap=AgentState,
        )
    @state.setter
    def state(self, value: "AgentState|version_service_pb2.AgentState|None") -> None:
        return super()._set_field("state",value,explicit_presence=False,
        )
    
    @builtins.property
    def messages(self) -> "abc.MutableSequence[builtins.str]":
        """
        Status messages describing the module's state.
        """
        
        return super()._get_field("messages", explicit_presence=False,
        wrap=pb_classes.Repeated,
        )
    @messages.setter
    def messages(self, value: "abc.Iterable[builtins.str]|None") -> None:
        return super()._set_field("messages",value,explicit_presence=False,
        )
    
    @builtins.property
    def parameters(self) -> "abc.MutableSequence[Parameter]":
        """
        Current parameters of the module.
        """
        
        return super()._get_field("parameters", explicit_presence=False,
        wrap=pb_classes.Repeated.with_wrap(Parameter,None,None),
        )
    @parameters.setter
    def parameters(self, value: "abc.Iterable[Parameter]|None") -> None:
        return super()._set_field("parameters",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "state":"state",
        "messages":"messages",
        "parameters":"parameters",
    }
    
class Parameter(pb_classes.Message):
    """
    Key-value parameter for module configuration.
    """
    
    __PB2_CLASS__ = version_service_pb2.Parameter
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.logging.agentmanager.v1.Parameter",version_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message.Message|None = None,
        *,
        name: "builtins.str|None|unset.UnsetType" = unset.Unset,
        value: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(name, unset.UnsetType):
            self.name = name
        if not isinstance(value, unset.UnsetType):
            self.value = value
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "name",
            "value",
        ]
    
    @builtins.property
    def name(self) -> "builtins.str":
        """
        Name of the parameter.
        """
        
        return super()._get_field("name", explicit_presence=False,
        )
    @name.setter
    def name(self, value: "builtins.str|None") -> None:
        return super()._set_field("name",value,explicit_presence=False,
        )
    
    @builtins.property
    def value(self) -> "builtins.str":
        """
        Value of the parameter.
        """
        
        return super()._get_field("value", explicit_presence=False,
        )
    @value.setter
    def value(self, value: "builtins.str|None") -> None:
        return super()._set_field("value",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "name":"name",
        "value":"value",
    }
    
class OSInfo(pb_classes.Message):
    """
    Operating system information for the instance.
    """
    
    __PB2_CLASS__ = version_service_pb2.OSInfo
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.logging.agentmanager.v1.OSInfo",version_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message.Message|None = None,
        *,
        name: "builtins.str|None|unset.UnsetType" = unset.Unset,
        uname: "builtins.str|None|unset.UnsetType" = unset.Unset,
        architecture: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(name, unset.UnsetType):
            self.name = name
        if not isinstance(uname, unset.UnsetType):
            self.uname = uname
        if not isinstance(architecture, unset.UnsetType):
            self.architecture = architecture
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "name",
            "uname",
            "architecture",
        ]
    
    @builtins.property
    def name(self) -> "builtins.str":
        """
        Operating system name and version.
        Example: "Ubuntu 22.04.4 LTS"
        """
        
        return super()._get_field("name", explicit_presence=False,
        )
    @name.setter
    def name(self, value: "builtins.str|None") -> None:
        return super()._set_field("name",value,explicit_presence=False,
        )
    
    @builtins.property
    def uname(self) -> "builtins.str":
        """
        Detailed system information from uname command.
        Example: "Linux computeimage-abcdef 6.5.0-44-generic #44~22.04.1-Ubuntu SMP PREEMPT_DYNAMIC Tue Jun 18 14:36:16 UTC 2 x86_64 x86_64 x86_64 GNU/Linux"
        """
        
        return super()._get_field("uname", explicit_presence=False,
        )
    @uname.setter
    def uname(self, value: "builtins.str|None") -> None:
        return super()._set_field("uname",value,explicit_presence=False,
        )
    
    @builtins.property
    def architecture(self) -> "builtins.str":
        """
        System architecture.
        """
        
        return super()._get_field("architecture", explicit_presence=False,
        )
    @architecture.setter
    def architecture(self, value: "builtins.str|None") -> None:
        return super()._set_field("architecture",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "name":"name",
        "uname":"uname",
        "architecture":"architecture",
    }
    
class GetVersionResponse(pb_classes.Message):
    """
    Response message for GetVersion RPC containing required action for the agent.
    """
    
    __PB2_CLASS__ = version_service_pb2.GetVersionResponse
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.logging.agentmanager.v1.GetVersionResponse",version_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    class __OneOfClass_response__(pb_classes.OneOf):
        name: builtins.str= "response"
        
        def __init__(self, msg: "GetVersionResponse") -> None:
            super().__init__()
            self._message: "GetVersionResponse" = msg
    
    class __OneOfClass_response_nop__(__OneOfClass_response__):
        field: typing.Literal["nop"] = "nop"
        
        def __init__(self, msg: "GetVersionResponse") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "NopActionParams":
            return self._message.nop
    
    class __OneOfClass_response_update__(__OneOfClass_response__):
        field: typing.Literal["update"] = "update"
        
        def __init__(self, msg: "GetVersionResponse") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "UpdateActionParams":
            return self._message.update
    
    class __OneOfClass_response_restart__(__OneOfClass_response__):
        field: typing.Literal["restart"] = "restart"
        
        def __init__(self, msg: "GetVersionResponse") -> None:
            super().__init__(msg)
        @builtins.property
        def value(self) -> "RestartActionParams":
            return self._message.restart
    
    @builtins.property
    def response(self) -> __OneOfClass_response_nop__|__OneOfClass_response_update__|__OneOfClass_response_restart__|None:
        """
        Parameters specific to the required action.
        """
        
        field_name: str|None = super().which_field_in_oneof("response")
        match field_name:
            case "nop":
                return self.__OneOfClass_response_nop__(self)
            case "update":
                return self.__OneOfClass_response_update__(self)
            case "restart":
                return self.__OneOfClass_response_restart__(self)
            case None:
                return None
            case _:
                raise pb_classes.OneOfMatchError(field_name)
    
    def __init__(
        self,
        initial_message: message.Message|None = None,
        *,
        action: "Action|version_service_pb2.Action|None|unset.UnsetType" = unset.Unset,
        nop: "NopActionParams|version_service_pb2.NopActionParams|None|unset.UnsetType" = unset.Unset,
        update: "UpdateActionParams|version_service_pb2.UpdateActionParams|None|unset.UnsetType" = unset.Unset,
        restart: "RestartActionParams|version_service_pb2.RestartActionParams|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(action, unset.UnsetType):
            self.action = action
        if not isinstance(nop, unset.UnsetType):
            self.nop = nop
        if not isinstance(update, unset.UnsetType):
            self.update = update
        if not isinstance(restart, unset.UnsetType):
            self.restart = restart
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "action",
            "nop",
            "update",
            "restart",
            "response",
        ]
    
    @builtins.property
    def action(self) -> "Action":
        """
        Required action for the agent to take.
        """
        
        return super()._get_field("action", explicit_presence=False,
        wrap=Action,
        )
    @action.setter
    def action(self, value: "Action|version_service_pb2.Action|None") -> None:
        return super()._set_field("action",value,explicit_presence=False,
        )
    
    @builtins.property
    def nop(self) -> "NopActionParams|None":
        """
        Parameters for no-operation action.
        """
        
        return super()._get_field("nop", explicit_presence=True,
        wrap=NopActionParams,
        )
    @nop.setter
    def nop(self, value: "NopActionParams|version_service_pb2.NopActionParams|None") -> None:
        return super()._set_field("nop",value,explicit_presence=True,
        )
    
    @builtins.property
    def update(self) -> "UpdateActionParams|None":
        """
        Parameters for update action.
        """
        
        return super()._get_field("update", explicit_presence=True,
        wrap=UpdateActionParams,
        )
    @update.setter
    def update(self, value: "UpdateActionParams|version_service_pb2.UpdateActionParams|None") -> None:
        return super()._set_field("update",value,explicit_presence=True,
        )
    
    @builtins.property
    def restart(self) -> "RestartActionParams|None":
        """
        Parameters for restart action.
        """
        
        return super()._get_field("restart", explicit_presence=True,
        wrap=RestartActionParams,
        )
    @restart.setter
    def restart(self, value: "RestartActionParams|version_service_pb2.RestartActionParams|None") -> None:
        return super()._set_field("restart",value,explicit_presence=True,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "action":"action",
        "nop":"nop",
        "update":"update",
        "restart":"restart",
        "response":"response",
    }
    
class NopActionParams(pb_classes.Message):
    """
    Parameters when no operation is required.
    """
    
    __PB2_CLASS__ = version_service_pb2.NopActionParams
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.logging.agentmanager.v1.NopActionParams",version_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message.Message|None = None,
    ) -> None:
        super().__init__(initial_message)
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
        ]
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
    }
    
class UpdateActionParams(pb_classes.Message):
    """
    Parameters for agent update action.
    """
    
    __PB2_CLASS__ = version_service_pb2.UpdateActionParams
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.logging.agentmanager.v1.UpdateActionParams",version_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message.Message|None = None,
        *,
        version: "builtins.str|None|unset.UnsetType" = unset.Unset,
        repo_url: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(version, unset.UnsetType):
            self.version = version
        if not isinstance(repo_url, unset.UnsetType):
            self.repo_url = repo_url
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "version",
            "repo_url",
        ]
    
    @builtins.property
    def version(self) -> "builtins.str":
        """
        Target version for the update.
        """
        
        return super()._get_field("version", explicit_presence=False,
        )
    @version.setter
    def version(self, value: "builtins.str|None") -> None:
        return super()._set_field("version",value,explicit_presence=False,
        )
    
    @builtins.property
    def repo_url(self) -> "builtins.str":
        """
        URL of the repository containing the update.
        """
        
        return super()._get_field("repo_url", explicit_presence=False,
        )
    @repo_url.setter
    def repo_url(self, value: "builtins.str|None") -> None:
        return super()._set_field("repo_url",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "version":"version",
        "repo_url":"repo_url",
    }
    
class RestartActionParams(pb_classes.Message):
    """
    Parameters for agent restart action.
    """
    
    __PB2_CLASS__ = version_service_pb2.RestartActionParams
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.logging.agentmanager.v1.RestartActionParams",version_service_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message.Message|None = None,
    ) -> None:
        super().__init__(initial_message)
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
        ]
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
    }
    

class VersionServiceClient(client.Client):
    """
    VersionService provides functionality for managing nebius-observability-agent versions and health status
    in the Nebius observability system.
    
    This class provides the client methods for the ``.nebius.logging.agentmanager.v1.VersionService`` service.
    
    Each method constructs a :class:`nebius.aio.request.Request` object
    that represents the in-flight RPC. The request can be awaited (async)
    or waited synchronously using its ``.wait()`` helpers.
    
    The request methods accept various parameters to configure metadata,
    timeouts, authorization, and retries. See individual method docstrings
    for details.
    
    :cvar __service_name__: The full protobuf service name.
    """
    
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.ServiceDescriptor](".nebius.logging.agentmanager.v1.VersionService",version_service_pb2.DESCRIPTOR,descriptor_1.ServiceDescriptor)
    """The protobuf service descriptor extraction function."""
    __service_name__ = ".nebius.logging.agentmanager.v1.VersionService"
    
    def get_version(self,
        request: "GetVersionRequest",
        **kwargs: typing_extensions.Unpack[request_kwargs.RequestKwargs]
    ) -> request.Request["GetVersionRequest","GetVersionResponse"]:
        """
        GetVersion retrieves version information and receives instructions for agent updates
        or maintenance based on the current state and health of the agent.
        
        :param request: The request object to send.
        :type request: :class:`nebius.api.nebius.logging.agentmanager.v1.GetVersionRequest`
        
        Other parameters can be provided as keyword arguments in the
        ``**kwargs`` dictionary, including metadata, timeouts, and retries.
        See :class:`nebius.aio.request_kwargs.RequestKwargs` for details.
        
        :return: A :class:`nebius.aio.request.Request` object representing the
            in-flight RPC. It can be awaited (async) or waited
            synchronously using its ``.wait()`` helpers.
        :rtype: :class:`nebius.aio.request.Request` of
            :class:`nebius.api.nebius.logging.agentmanager.v1.GetVersionResponse`.
        """
        
        return super().request(
            method="GetVersion",
            request=request,
            result_pb2_class=version_service_pb2.GetVersionResponse,
            result_wrapper=pb_classes.simple_wrapper(GetVersionResponse),
            **kwargs,
        )
    

__all__ = [
    #@ local import names here @#
    "AgentType",
    "AgentState",
    "Action",
    "GetVersionRequest",
    "ModulesHealth",
    "ModuleHealth",
    "Parameter",
    "OSInfo",
    "GetVersionResponse",
    "NopActionParams",
    "UpdateActionParams",
    "RestartActionParams",
    "VersionServiceClient",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/invitation_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import invitation_pb2 as nebius_dot_iam_dot_v1_dot_invitation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/iam/v1/invitation_service.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1enebius/iam/v1/invitation.proto\"\xa5\x01\n\x17\x43reateInvitationRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.iam.v1.InvitationSpecR\x04spec\x12\x17\n\x07no_send\x18\x03 \x01(\x08R\x06noSend\".\n\x14GetInvitationRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x96\x01\n\x16ListInvitationsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x1b\n\x06\x66ilter\x18\x04 \x01(\tB\x03\xc0J\x01R\x06\x66ilter\"r\n\x17ListInvitationsResponse\x12/\n\x05items\x18\x01 \x03(\x0b\x32\x19.nebius.iam.v1.InvitationR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"1\n\x17\x44\x65leteInvitationRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x8c\x01\n\x17UpdateInvitationRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.iam.v1.InvitationSpecR\x04spec\"1\n\x17ResendInvitationRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\xf9\x03\n\x11InvitationService\x12M\n\x06\x43reate\x12&.nebius.iam.v1.CreateInvitationRequest\x1a\x1b.nebius.common.v1.Operation\x12\x45\n\x03Get\x12#.nebius.iam.v1.GetInvitationRequest\x1a\x19.nebius.iam.v1.Invitation\x12U\n\x04List\x12%.nebius.iam.v1.ListInvitationsRequest\x1a&.nebius.iam.v1.ListInvitationsResponse\x12M\n\x06\x44\x65lete\x12&.nebius.iam.v1.DeleteInvitationRequest\x1a\x1b.nebius.common.v1.Operation\x12M\n\x06Update\x12&.nebius.iam.v1.UpdateInvitationRequest\x1a\x1b.nebius.common.v1.Operation\x12M\n\x06Resend\x12&.nebius.iam.v1.ResendInvitationRequest\x1a\x1b.nebius.common.v1.Operation\x1a\n\xbaJ\x07\x63pl.iamB]\n\x14\x61i.nebius.pub.iam.v1B\x16InvitationServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.invitation_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\026InvitationServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _GETINVITATIONREQUEST.fields_by_name['id']._options = None
  _GETINVITATIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTINVITATIONSREQUEST.fields_by_name['parent_id']._options = None
  _LISTINVITATIONSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTINVITATIONSREQUEST.fields_by_name['filter']._options = None
  _LISTINVITATIONSREQUEST.fields_by_name['filter']._serialized_options = b'\300J\001'
  _DELETEINVITATIONREQUEST.fields_by_name['id']._options = None
  _DELETEINVITATIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _RESENDINVITATIONREQUEST.fields_by_name['id']._options = None
  _RESENDINVITATIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _INVITATIONSERVICE._options = None
  _INVITATIONSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_CREATEINVITATIONREQUEST']._serialized_start=212
  _globals['_CREATEINVITATIONREQUEST']._serialized_end=377
  _globals['_GETINVITATIONREQUEST']._serialized_start=379
  _globals['_GETINVITATIONREQUEST']._serialized_end=425
  _globals['_LISTINVITATIONSREQUEST']._serialized_start=428
  _globals['_LISTINVITATIONSREQUEST']._serialized_end=578
  _globals['_LISTINVITATIONSRESPONSE']._serialized_start=580
  _globals['_LISTINVITATIONSRESPONSE']._serialized_end=694
  _globals['_DELETEINVITATIONREQUEST']._serialized_start=696
  _globals['_DELETEINVITATIONREQUEST']._serialized_end=745
  _globals['_UPDATEINVITATIONREQUEST']._serialized_start=748
  _globals['_UPDATEINVITATIONREQUEST']._serialized_end=888
  _globals['_RESENDINVITATIONREQUEST']._serialized_start=890
  _globals['_RESENDINVITATIONREQUEST']._serialized_end=939
  _globals['_INVITATIONSERVICE']._serialized_start=942
  _globals['_INVITATIONSERVICE']._serialized_end=1447
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/iam/v1/federation_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.iam.v1 import federation_pb2 as nebius_dot_iam_dot_v1_dot_federation__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n&nebius/iam/v1/federation_service.proto\x12\rnebius.iam.v1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a\x1enebius/iam/v1/federation.proto\"\x8c\x01\n\x17\x43reateFederationRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.iam.v1.FederationSpecR\x04spec\".\n\x14GetFederationRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x91\x01\n\x16ListFederationsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\x12\x16\n\x06\x66ilter\x18\x04 \x01(\tR\x06\x66ilter\"r\n\x17ListFederationsResponse\x12/\n\x05items\x18\x01 \x03(\x0b\x32\x19.nebius.iam.v1.FederationR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xc5\x01\n\x17UpdateFederationRequest\x12>\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataR\x08metadata\x12\x31\n\x04spec\x18\x02 \x01(\x0b\x32\x1d.nebius.iam.v1.FederationSpecR\x04spec\x12\x37\n\x06status\x18\x03 \x01(\x0b\x32\x1f.nebius.iam.v1.FederationStatusR\x06status\"1\n\x17\x44\x65leteFederationRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\xf6\x03\n\x11\x46\x65\x64\x65rationService\x12M\n\x06\x43reate\x12&.nebius.iam.v1.CreateFederationRequest\x1a\x1b.nebius.common.v1.Operation\x12\x45\n\x03Get\x12#.nebius.iam.v1.GetFederationRequest\x1a\x19.nebius.iam.v1.Federation\x12J\n\tGetByName\x12\".nebius.common.v1.GetByNameRequest\x1a\x19.nebius.iam.v1.Federation\x12U\n\x04List\x12%.nebius.iam.v1.ListFederationsRequest\x1a&.nebius.iam.v1.ListFederationsResponse\x12M\n\x06Update\x12&.nebius.iam.v1.UpdateFederationRequest\x1a\x1b.nebius.common.v1.Operation\x12M\n\x06\x44\x65lete\x12&.nebius.iam.v1.DeleteFederationRequest\x1a\x1b.nebius.common.v1.Operation\x1a\n\xbaJ\x07\x63pl.iamB]\n\x14\x61i.nebius.pub.iam.v1B\x16\x46\x65\x64\x65rationServiceProtoP\x01Z+github.com/nebius/gosdk/proto/nebius/iam/v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.iam.v1.federation_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\024ai.nebius.pub.iam.v1B\026FederationServiceProtoP\001Z+github.com/nebius/gosdk/proto/nebius/iam/v1'
  _GETFEDERATIONREQUEST.fields_by_name['id']._options = None
  _GETFEDERATIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _LISTFEDERATIONSREQUEST.fields_by_name['parent_id']._options = None
  _LISTFEDERATIONSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _DELETEFEDERATIONREQUEST.fields_by_name['id']._options = None
  _DELETEFEDERATIONREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _FEDERATIONSERVICE._options = None
  _FEDERATIONSERVICE._serialized_options = b'\272J\007cpl.iam'
  _globals['_CREATEFEDERATIONREQUEST']._serialized_start=212
  _globals['_CREATEFEDERATIONREQUEST']._serialized_end=352
  _globals['_GETFEDERATIONREQUEST']._serialized_start=354
  _globals['_GETFEDERATIONREQUEST']._serialized_end=400
  _globals['_LISTFEDERATIONSREQUEST']._serialized_start=403
  _globals['_LISTFEDERATIONSREQUEST']._serialized_end=548
  _globals['_LISTFEDERATIONSRESPONSE']._serialized_start=550
  _globals['_LISTFEDERATIONSRESPONSE']._serialized_end=664
  _globals['_UPDATEFEDERATIONREQUEST']._serialized_start=667
  _globals['_UPDATEFEDERATIONREQUEST']._serialized_end=864
  _globals['_DELETEFEDERATIONREQUEST']._serialized_start=866
  _globals['_DELETEFEDERATIONREQUEST']._serialized_end=915
  _globals['_FEDERATIONSERVICE']._serialized_start=918
  _globals['_FEDERATIONSERVICE']._serialized_end=1420
# @@protoc_insertion_point(module_scope)



from nebius.api.buf.validate import validate_pb2 as _validate_pb2
from nebius.api.nebius.audit.v2 import resource_metadata_pb2 as _resource_metadata_pb2
from nebius.api.nebius.audit.v2 import resource_state_pb2 as _resource_state_pb2
from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Resource(_message.Message):
    __slots__ = ["metadata", "state", "hierarchy"]
    METADATA_FIELD_NUMBER: _ClassVar[int]
    STATE_FIELD_NUMBER: _ClassVar[int]
    HIERARCHY_FIELD_NUMBER: _ClassVar[int]
    metadata: _resource_metadata_pb2.ResourceMetadata
    state: _resource_state_pb2.ResourceState
    hierarchy: _containers.RepeatedCompositeFieldContainer[_resource_metadata_pb2.ResourceMetadata]
    def __init__(self, metadata: _Optional[_Union[_resource_metadata_pb2.ResourceMetadata, _Mapping]] = ..., state: _Optional[_Union[_resource_state_pb2.ResourceState, _Mapping]] = ..., hierarchy: _Optional[_Iterable[_Union[_resource_metadata_pb2.ResourceMetadata, _Mapping]]] = ...) -> None: ...



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mk8s/v1alpha1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1alpha1 import operation_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__pb2
from nebius.api.nebius.mk8s.v1alpha1 import cluster_pb2 as nebius_dot_mk8s_dot_v1alpha1_dot_cluster__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n*nebius/mk8s/v1alpha1/cluster_service.proto\x12\x14nebius.mk8s.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a&nebius/common/v1alpha1/operation.proto\x1a\"nebius/mk8s/v1alpha1/cluster.proto\"\x9d\x01\n\x14\x43reateClusterRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12=\n\x04spec\x18\x02 \x01(\x0b\x32!.nebius.mk8s.v1alpha1.ClusterSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"V\n\x11GetClusterRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\"Z\n\x17GetClusterByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"v\n\x13ListClustersRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"s\n\x14ListClustersResponse\x12\x33\n\x05items\x18\x01 \x03(\x0b\x32\x1d.nebius.mk8s.v1alpha1.ClusterR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\x95\x01\n\x14UpdateClusterRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x35\n\x04spec\x18\x02 \x01(\x0b\x32!.nebius.mk8s.v1alpha1.ClusterSpecR\x04spec\".\n\x14\x44\x65leteClusterRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"(\n&ListClusterControlPlaneVersionsRequest\"q\n\'ListClusterControlPlaneVersionsResponse\x12\x46\n\x05items\x18\x01 \x03(\x0b\x32\x30.nebius.mk8s.v1alpha1.ClusterControlPlaneVersionR\x05items\"6\n\x1a\x43lusterControlPlaneVersion\x12\x18\n\x07version\x18\x01 \x01(\tR\x07version2\x88\x06\n\x0e\x43lusterService\x12M\n\x03Get\x12\'.nebius.mk8s.v1alpha1.GetClusterRequest\x1a\x1d.nebius.mk8s.v1alpha1.Cluster\x12Y\n\tGetByName\x12-.nebius.mk8s.v1alpha1.GetClusterByNameRequest\x1a\x1d.nebius.mk8s.v1alpha1.Cluster\x12]\n\x04List\x12).nebius.mk8s.v1alpha1.ListClustersRequest\x1a*.nebius.mk8s.v1alpha1.ListClustersResponse\x12W\n\x06\x43reate\x12*.nebius.mk8s.v1alpha1.CreateClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12W\n\x06Update\x12*.nebius.mk8s.v1alpha1.UpdateClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12W\n\x06\x44\x65lete\x12*.nebius.mk8s.v1alpha1.DeleteClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12\x97\x01\n\x18ListControlPlaneVersions\x12<.nebius.mk8s.v1alpha1.ListClusterControlPlaneVersionsRequest\x1a=.nebius.mk8s.v1alpha1.ListClusterControlPlaneVersionsResponse\x1aH\x88\x02\x01\xbaJ\x04mk8s\xd2J;\x12\x39\x43luster v1alpha1 API is deprecated, please migrate to v1.B}\n\x1b\x61i.nebius.pub.mk8s.v1alpha1B\x13\x43lusterServiceProtoP\x01Z2github.com/nebius/gosdk/proto/nebius/mk8s/v1alpha1\xb8\x01\x01\xd2J\x0f\x12\rmigrate to v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mk8s.v1alpha1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033ai.nebius.pub.mk8s.v1alpha1B\023ClusterServiceProtoP\001Z2github.com/nebius/gosdk/proto/nebius/mk8s/v1alpha1\270\001\001\322J\017\022\rmigrate to v1'
  _CREATECLUSTERREQUEST.fields_by_name['metadata']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CREATECLUSTERREQUEST.fields_by_name['spec']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _GETCLUSTERREQUEST.fields_by_name['id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETCLUSTERBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETCLUSTERBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETCLUSTERBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETCLUSTERBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTCLUSTERSREQUEST.fields_by_name['parent_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _UPDATECLUSTERREQUEST.fields_by_name['metadata']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _DELETECLUSTERREQUEST.fields_by_name['id']._options = None
  _DELETECLUSTERREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTERSERVICE._options = None
  _CLUSTERSERVICE._serialized_options = b'\210\002\001\272J\004mk8s\322J;\0229Cluster v1alpha1 API is deprecated, please migrate to v1.'
  _globals['_CREATECLUSTERREQUEST']._serialized_start=233
  _globals['_CREATECLUSTERREQUEST']._serialized_end=390
  _globals['_GETCLUSTERREQUEST']._serialized_start=392
  _globals['_GETCLUSTERREQUEST']._serialized_end=478
  _globals['_GETCLUSTERBYNAMEREQUEST']._serialized_start=480
  _globals['_GETCLUSTERBYNAMEREQUEST']._serialized_end=570
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=572
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=690
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=692
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=807
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=810
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=959
  _globals['_DELETECLUSTERREQUEST']._serialized_start=961
  _globals['_DELETECLUSTERREQUEST']._serialized_end=1007
  _globals['_LISTCLUSTERCONTROLPLANEVERSIONSREQUEST']._serialized_start=1009
  _globals['_LISTCLUSTERCONTROLPLANEVERSIONSREQUEST']._serialized_end=1049
  _globals['_LISTCLUSTERCONTROLPLANEVERSIONSRESPONSE']._serialized_start=1051
  _globals['_LISTCLUSTERCONTROLPLANEVERSIONSRESPONSE']._serialized_end=1164
  _globals['_CLUSTERCONTROLPLANEVERSION']._serialized_start=1166
  _globals['_CLUSTERCONTROLPLANEVERSION']._serialized_end=1220
  _globals['_CLUSTERSERVICE']._serialized_start=1223
  _globals['_CLUSTERSERVICE']._serialized_end=1999
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/mk8s/v1alpha1/node_group_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1alpha1 import operation_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__pb2
from nebius.api.nebius.mk8s.v1alpha1 import node_group_pb2 as nebius_dot_mk8s_dot_v1alpha1_dot_node__group__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n-nebius/mk8s/v1alpha1/node_group_service.proto\x12\x14nebius.mk8s.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x1bgoogle/protobuf/empty.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a&nebius/common/v1alpha1/operation.proto\x1a%nebius/mk8s/v1alpha1/node_group.proto\"\xa1\x01\n\x16\x43reateNodeGroupRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12?\n\x04spec\x18\x02 \x01(\x0b\x32#.nebius.mk8s.v1alpha1.NodeGroupSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"X\n\x13GetNodeGroupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12)\n\x10resource_version\x18\x02 \x01(\tR\x0fresourceVersion\"\\\n\x19GetNodeGroupByNameRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1a\n\x04name\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x04name\"x\n\x15ListNodeGroupsRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"w\n\x16ListNodeGroupsResponse\x12\x35\n\x05items\x18\x01 \x03(\x0b\x32\x1f.nebius.mk8s.v1alpha1.NodeGroupR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\x99\x01\n\x16UpdateNodeGroupRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12\x37\n\x04spec\x18\x02 \x01(\x0b\x32#.nebius.mk8s.v1alpha1.NodeGroupSpecR\x04spec\"0\n\x16\x44\x65leteNodeGroupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"\x9a\x01\n\x17UpgradeNodeGroupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12P\n\x14latest_infra_version\x18\x02 \x01(\x0b\x32\x16.google.protobuf.EmptyB\x04\xbaJ\x01\x06H\x00R\x12latestInfraVersionB\x15\n\x0cupgrade_type\x12\x05\xbaH\x02\x08\x01\x32\xe1\x05\n\x10NodeGroupService\x12Q\n\x03Get\x12).nebius.mk8s.v1alpha1.GetNodeGroupRequest\x1a\x1f.nebius.mk8s.v1alpha1.NodeGroup\x12]\n\tGetByName\x12/.nebius.mk8s.v1alpha1.GetNodeGroupByNameRequest\x1a\x1f.nebius.mk8s.v1alpha1.NodeGroup\x12\x61\n\x04List\x12+.nebius.mk8s.v1alpha1.ListNodeGroupsRequest\x1a,.nebius.mk8s.v1alpha1.ListNodeGroupsResponse\x12Y\n\x06\x43reate\x12,.nebius.mk8s.v1alpha1.CreateNodeGroupRequest\x1a!.nebius.common.v1alpha1.Operation\x12Y\n\x06Update\x12,.nebius.mk8s.v1alpha1.UpdateNodeGroupRequest\x1a!.nebius.common.v1alpha1.Operation\x12Y\n\x06\x44\x65lete\x12,.nebius.mk8s.v1alpha1.DeleteNodeGroupRequest\x1a!.nebius.common.v1alpha1.Operation\x12[\n\x07Upgrade\x12-.nebius.mk8s.v1alpha1.UpgradeNodeGroupRequest\x1a!.nebius.common.v1alpha1.Operation\x1aJ\x88\x02\x01\xbaJ\x04mk8s\xd2J=\x12;NodeGroup v1alpha1 API is deprecated, please migrate to v1.B\x7f\n\x1b\x61i.nebius.pub.mk8s.v1alpha1B\x15NodeGroupServiceProtoP\x01Z2github.com/nebius/gosdk/proto/nebius/mk8s/v1alpha1\xb8\x01\x01\xd2J\x0f\x12\rmigrate to v1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.mk8s.v1alpha1.node_group_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n\033ai.nebius.pub.mk8s.v1alpha1B\025NodeGroupServiceProtoP\001Z2github.com/nebius/gosdk/proto/nebius/mk8s/v1alpha1\270\001\001\322J\017\022\rmigrate to v1'
  _CREATENODEGROUPREQUEST.fields_by_name['metadata']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CREATENODEGROUPREQUEST.fields_by_name['spec']._options = None
  _CREATENODEGROUPREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _GETNODEGROUPREQUEST.fields_by_name['id']._options = None
  _GETNODEGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETNODEGROUPBYNAMEREQUEST.fields_by_name['parent_id']._options = None
  _GETNODEGROUPBYNAMEREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _GETNODEGROUPBYNAMEREQUEST.fields_by_name['name']._options = None
  _GETNODEGROUPBYNAMEREQUEST.fields_by_name['name']._serialized_options = b'\272H\003\310\001\001'
  _LISTNODEGROUPSREQUEST.fields_by_name['parent_id']._options = None
  _LISTNODEGROUPSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _UPDATENODEGROUPREQUEST.fields_by_name['metadata']._options = None
  _UPDATENODEGROUPREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _DELETENODEGROUPREQUEST.fields_by_name['id']._options = None
  _DELETENODEGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UPGRADENODEGROUPREQUEST.oneofs_by_name['upgrade_type']._options = None
  _UPGRADENODEGROUPREQUEST.oneofs_by_name['upgrade_type']._serialized_options = b'\272H\002\010\001'
  _UPGRADENODEGROUPREQUEST.fields_by_name['id']._options = None
  _UPGRADENODEGROUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _UPGRADENODEGROUPREQUEST.fields_by_name['latest_infra_version']._options = None
  _UPGRADENODEGROUPREQUEST.fields_by_name['latest_infra_version']._serialized_options = b'\272J\001\006'
  _NODEGROUPSERVICE._options = None
  _NODEGROUPSERVICE._serialized_options = b'\210\002\001\272J\004mk8s\322J=\022;NodeGroup v1alpha1 API is deprecated, please migrate to v1.'
  _globals['_CREATENODEGROUPREQUEST']._serialized_start=268
  _globals['_CREATENODEGROUPREQUEST']._serialized_end=429
  _globals['_GETNODEGROUPREQUEST']._serialized_start=431
  _globals['_GETNODEGROUPREQUEST']._serialized_end=519
  _globals['_GETNODEGROUPBYNAMEREQUEST']._serialized_start=521
  _globals['_GETNODEGROUPBYNAMEREQUEST']._serialized_end=613
  _globals['_LISTNODEGROUPSREQUEST']._serialized_start=615
  _globals['_LISTNODEGROUPSREQUEST']._serialized_end=735
  _globals['_LISTNODEGROUPSRESPONSE']._serialized_start=737
  _globals['_LISTNODEGROUPSRESPONSE']._serialized_end=856
  _globals['_UPDATENODEGROUPREQUEST']._serialized_start=859
  _globals['_UPDATENODEGROUPREQUEST']._serialized_end=1012
  _globals['_DELETENODEGROUPREQUEST']._serialized_start=1014
  _globals['_DELETENODEGROUPREQUEST']._serialized_end=1062
  _globals['_UPGRADENODEGROUPREQUEST']._serialized_start=1065
  _globals['_UPGRADENODEGROUPREQUEST']._serialized_end=1219
  _globals['_NODEGROUPSERVICE']._serialized_start=1222
  _globals['_NODEGROUPSERVICE']._serialized_end=1959
# @@protoc_insertion_point(module_scope)



# 
# Generated by the nebius.base.protos.compiler.  DO NOT EDIT!
# 

"""Auto-generated Nebius SDK package for ``nebius.msp.v1alpha1``"""

import builtins as builtins
import collections.abc as abc
import google.protobuf.descriptor as descriptor_1
import google.protobuf.message as message_1
import nebius.api.nebius.msp.v1alpha1.cluster_pb2 as cluster_pb2
import nebius.api.nebius.msp.v1alpha1.common_pb2 as common_pb2
import nebius.base.protos.descriptor as descriptor
import nebius.base.protos.pb_classes as pb_classes
import nebius.base.protos.pb_enum as pb_enum
import nebius.base.protos.unset as unset
#@ local imports here @#

# file: nebius/msp/v1alpha1/cluster.proto
class ClusterStatus(pb_classes.Message):
    __PB2_CLASS__ = cluster_pb2.ClusterStatus
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.ClusterStatus",cluster_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    class Phase(pb_enum.Enum):
        __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.msp.v1alpha1.ClusterStatus.Phase",cluster_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
        PHASE_UNSPECIFIED = 0
        PHASE_PROVISIONING = 1
        PHASE_RUNNING = 2
        PHASE_UPDATING = 3
        PHASE_DELETING = 4
        PHASE_DELETED = 5
        PHASE_PURGING = 6
        PHASE_STOPPING = 7
        PHASE_RESUMING = 8
    
    class State(pb_enum.Enum):
        __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.EnumDescriptor](".nebius.msp.v1alpha1.ClusterStatus.State",cluster_pb2.DESCRIPTOR,descriptor_1.EnumDescriptor)
        STATE_UNSPECIFIED = 0
        STATE_IN_PROGRESS = 1
        STATE_FINISHED = 2
        STATE_ERROR = 3
        STATE_DEGRADED = 4
        STATE_SCHEDULED = 5
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        phase: "ClusterStatus.Phase|cluster_pb2.ClusterStatus.Phase|None|unset.UnsetType" = unset.Unset,
        state: "ClusterStatus.State|cluster_pb2.ClusterStatus.State|None|unset.UnsetType" = unset.Unset,
        reconciling: "builtins.bool|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(phase, unset.UnsetType):
            self.phase = phase
        if not isinstance(state, unset.UnsetType):
            self.state = state
        if not isinstance(reconciling, unset.UnsetType):
            self.reconciling = reconciling
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "phase",
            "state",
            "reconciling",
            "Phase",
            "State",
        ]
    
    @builtins.property
    def phase(self) -> "ClusterStatus.Phase":
        """
        Current phase of the cluster.
        """
        
        return super()._get_field("phase", explicit_presence=False,
        wrap=ClusterStatus.Phase,
        )
    @phase.setter
    def phase(self, value: "ClusterStatus.Phase|cluster_pb2.ClusterStatus.Phase|None") -> None:
        return super()._set_field("phase",value,explicit_presence=False,
        )
    
    @builtins.property
    def state(self) -> "ClusterStatus.State":
        """
        State reflects substatus of the phase to define whether it's healthy or not.
        """
        
        return super()._get_field("state", explicit_presence=False,
        wrap=ClusterStatus.State,
        )
    @state.setter
    def state(self, value: "ClusterStatus.State|cluster_pb2.ClusterStatus.State|None") -> None:
        return super()._set_field("state",value,explicit_presence=False,
        )
    
    @builtins.property
    def reconciling(self) -> "builtins.bool":
        return super()._get_field("reconciling", explicit_presence=False,
        )
    @reconciling.setter
    def reconciling(self, value: "builtins.bool|None") -> None:
        return super()._set_field("reconciling",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "phase":"phase",
        "state":"state",
        "reconciling":"reconciling",
        "Phase":"Phase",
        "State":"State",
    }
    
# file: nebius/msp/v1alpha1/common.proto
class GetRequest(pb_classes.Message):
    __PB2_CLASS__ = common_pb2.GetRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.GetRequest",common_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        """
        ID of the entity to retrieve.
        """
        
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    
class GetByNameRequest(pb_classes.Message):
    __PB2_CLASS__ = common_pb2.GetByNameRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.GetByNameRequest",common_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        parent_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        name: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(parent_id, unset.UnsetType):
            self.parent_id = parent_id
        if not isinstance(name, unset.UnsetType):
            self.name = name
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "parent_id",
            "name",
        ]
    
    @builtins.property
    def parent_id(self) -> "builtins.str":
        """
        Parent ID of entity to retrieve.
        """
        
        return super()._get_field("parent_id", explicit_presence=False,
        )
    @parent_id.setter
    def parent_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("parent_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def name(self) -> "builtins.str":
        """
        Name of the entity to retrieve.
        """
        
        return super()._get_field("name", explicit_presence=False,
        )
    @name.setter
    def name(self, value: "builtins.str|None") -> None:
        return super()._set_field("name",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "parent_id":"parent_id",
        "name":"name",
    }
    
class DeleteRequest(pb_classes.Message):
    __PB2_CLASS__ = common_pb2.DeleteRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.DeleteRequest",common_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        """
        ID of the entity to delete.
        """
        
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    
class StartRequest(pb_classes.Message):
    __PB2_CLASS__ = common_pb2.StartRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.StartRequest",common_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        """
        ID of the entity to start.
        """
        
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    
class StopRequest(pb_classes.Message):
    __PB2_CLASS__ = common_pb2.StopRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.StopRequest",common_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        """
        ID of the entity to stop.
        """
        
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
    }
    
class ListRequest(pb_classes.Message):
    __PB2_CLASS__ = common_pb2.ListRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.ListRequest",common_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        parent_id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        page_size: "builtins.int|None|unset.UnsetType" = unset.Unset,
        page_token: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(parent_id, unset.UnsetType):
            self.parent_id = parent_id
        if not isinstance(page_size, unset.UnsetType):
            self.page_size = page_size
        if not isinstance(page_token, unset.UnsetType):
            self.page_token = page_token
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "parent_id",
            "page_size",
            "page_token",
        ]
    
    @builtins.property
    def parent_id(self) -> "builtins.str":
        """
        Identifier of IAM container to list from.
        """
        
        return super()._get_field("parent_id", explicit_presence=False,
        )
    @parent_id.setter
    def parent_id(self, value: "builtins.str|None") -> None:
        return super()._set_field("parent_id",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_size(self) -> "builtins.int":
        """
        Specifies the maximum number of items to return in the response. Default value is 100.
        """
        
        return super()._get_field("page_size", explicit_presence=False,
        )
    @page_size.setter
    def page_size(self, value: "builtins.int|None") -> None:
        return super()._set_field("page_size",value,explicit_presence=False,
        )
    
    @builtins.property
    def page_token(self) -> "builtins.str":
        """
        Token for pagination, allowing the retrieval of the next set of results.
        """
        
        return super()._get_field("page_token", explicit_presence=False,
        )
    @page_token.setter
    def page_token(self, value: "builtins.str|None") -> None:
        return super()._set_field("page_token",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "parent_id":"parent_id",
        "page_size":"page_size",
        "page_token":"page_token",
    }
    
class UpdateVersionRequest(pb_classes.Message):
    __PB2_CLASS__ = common_pb2.UpdateVersionRequest
    __PB2_DESCRIPTOR__ = descriptor.DescriptorWrap[descriptor_1.Descriptor](".nebius.msp.v1alpha1.UpdateVersionRequest",common_pb2.DESCRIPTOR,descriptor_1.Descriptor)
    __mask_functions__ = {
    }
    
    def __init__(
        self,
        initial_message: message_1.Message|None = None,
        *,
        id: "builtins.str|None|unset.UnsetType" = unset.Unset,
        version: "builtins.str|None|unset.UnsetType" = unset.Unset,
    ) -> None:
        super().__init__(initial_message)
        if not isinstance(id, unset.UnsetType):
            self.id = id
        if not isinstance(version, unset.UnsetType):
            self.version = version
    
    def __dir__(self) ->abc.Iterable[builtins.str]:
        return [
            "id",
            "version",
        ]
    
    @builtins.property
    def id(self) -> "builtins.str":
        """
        ID of the entity to stop.
        """
        
        return super()._get_field("id", explicit_presence=False,
        )
    @id.setter
    def id(self, value: "builtins.str|None") -> None:
        return super()._set_field("id",value,explicit_presence=False,
        )
    
    @builtins.property
    def version(self) -> "builtins.str":
        """
        New version string.
        """
        
        return super()._get_field("version", explicit_presence=False,
        )
    @version.setter
    def version(self, value: "builtins.str|None") -> None:
        return super()._set_field("version",value,explicit_presence=False,
        )
    
    __PY_TO_PB2__: builtins.dict[builtins.str,builtins.str] = {
        "id":"id",
        "version":"version",
    }
    
__all__ = [
    #@ local import names here @#
    "ClusterStatus",
    "GetRequest",
    "GetByNameRequest",
    "DeleteRequest",
    "StartRequest",
    "StopRequest",
    "ListRequest",
    "UpdateVersionRequest",
]



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/postgresql/v1alpha1/cluster_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius.msp.postgresql.v1alpha1 import cluster_pb2 as nebius_dot_msp_dot_postgresql_dot_v1alpha1_dot_cluster__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1alpha1 import operation_pb2 as nebius_dot_common_dot_v1alpha1_dot_operation__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4nebius/msp/postgresql/v1alpha1/cluster_service.proto\x12\x1enebius.msp.postgresql.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a,nebius/msp/postgresql/v1alpha1/cluster.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a&nebius/common/v1alpha1/operation.proto\x1a\x18nebius/annotations.proto\x1a\x1fgoogle/protobuf/timestamp.proto\"+\n\x11GetClusterRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"Y\n\x1aGetClusterForBackupRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\x12#\n\tbackup_id\x18\x02 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08\x62\x61\x63kupId\"v\n\x13ListClustersRequest\x12#\n\tparent_id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08parentId\x12\x1b\n\tpage_size\x18\x02 \x01(\x03R\x08pageSize\x12\x1d\n\npage_token\x18\x03 \x01(\tR\tpageToken\"\x83\x01\n\x14ListClustersResponse\x12\x43\n\x08\x63lusters\x18\x01 \x03(\x0b\x32\'.nebius.msp.postgresql.v1alpha1.ClusterR\x08\x63lusters\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken\"\xa7\x01\n\x14\x43reateClusterRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12G\n\x04spec\x18\x02 \x01(\x0b\x32+.nebius.msp.postgresql.v1alpha1.ClusterSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\"\xc2\x02\n\x15RestoreClusterRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12G\n\x04spec\x18\x02 \x01(\x0b\x32+.nebius.msp.postgresql.v1alpha1.ClusterSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12#\n\tbackup_id\x18\x03 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x08\x62\x61\x63kupId\x12\x32\n\x11source_cluster_id\x18\x04 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x0fsourceClusterId\x12?\n\rrecovery_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.TimestampR\x0crecoveryTime\"&\n\x14\x44\x65leteClusterRequest\x12\x0e\n\x02id\x18\x01 \x01(\tR\x02id\"\x9f\x01\n\x14UpdateClusterRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12?\n\x04spec\x18\x02 \x01(\x0b\x32+.nebius.msp.postgresql.v1alpha1.ClusterSpecR\x04spec\",\n\x12StopClusterRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id\"-\n\x13StartClusterRequest\x12\x16\n\x02id\x18\x01 \x01(\tB\x06\xbaH\x03\xc8\x01\x01R\x02id2\x96\x08\n\x0e\x43lusterService\x12\x61\n\x03Get\x12\x31.nebius.msp.postgresql.v1alpha1.GetClusterRequest\x1a\'.nebius.msp.postgresql.v1alpha1.Cluster\x12X\n\tGetByName\x12\".nebius.common.v1.GetByNameRequest\x1a\'.nebius.msp.postgresql.v1alpha1.Cluster\x12s\n\x0cGetForBackup\x12:.nebius.msp.postgresql.v1alpha1.GetClusterForBackupRequest\x1a\'.nebius.msp.postgresql.v1alpha1.Cluster\x12q\n\x04List\x12\x33.nebius.msp.postgresql.v1alpha1.ListClustersRequest\x1a\x34.nebius.msp.postgresql.v1alpha1.ListClustersResponse\x12\x61\n\x06\x43reate\x12\x34.nebius.msp.postgresql.v1alpha1.CreateClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12\x61\n\x06\x44\x65lete\x12\x34.nebius.msp.postgresql.v1alpha1.DeleteClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12\x61\n\x06Update\x12\x34.nebius.msp.postgresql.v1alpha1.UpdateClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12\x63\n\x07Restore\x12\x35.nebius.msp.postgresql.v1alpha1.RestoreClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12]\n\x04Stop\x12\x32.nebius.msp.postgresql.v1alpha1.StopClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x12_\n\x05Start\x12\x33.nebius.msp.postgresql.v1alpha1.StartClusterRequest\x1a!.nebius.common.v1alpha1.Operation\x1a\x11\xbaJ\x0epostgresql.mspB|\n%ai.nebius.pub.msp.postgresql.v1alpha1B\x13\x43lusterServiceProtoP\x01Z<github.com/nebius/gosdk/proto/nebius/msp/postgresql/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.postgresql.v1alpha1.cluster_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%ai.nebius.pub.msp.postgresql.v1alpha1B\023ClusterServiceProtoP\001Z<github.com/nebius/gosdk/proto/nebius/msp/postgresql/v1alpha1'
  _GETCLUSTERREQUEST.fields_by_name['id']._options = None
  _GETCLUSTERREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETCLUSTERFORBACKUPREQUEST.fields_by_name['id']._options = None
  _GETCLUSTERFORBACKUPREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _GETCLUSTERFORBACKUPREQUEST.fields_by_name['backup_id']._options = None
  _GETCLUSTERFORBACKUPREQUEST.fields_by_name['backup_id']._serialized_options = b'\272H\003\310\001\001'
  _LISTCLUSTERSREQUEST.fields_by_name['parent_id']._options = None
  _LISTCLUSTERSREQUEST.fields_by_name['parent_id']._serialized_options = b'\272H\003\310\001\001'
  _CREATECLUSTERREQUEST.fields_by_name['metadata']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CREATECLUSTERREQUEST.fields_by_name['spec']._options = None
  _CREATECLUSTERREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _RESTORECLUSTERREQUEST.fields_by_name['metadata']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _RESTORECLUSTERREQUEST.fields_by_name['spec']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _RESTORECLUSTERREQUEST.fields_by_name['backup_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['backup_id']._serialized_options = b'\272H\003\310\001\001'
  _RESTORECLUSTERREQUEST.fields_by_name['source_cluster_id']._options = None
  _RESTORECLUSTERREQUEST.fields_by_name['source_cluster_id']._serialized_options = b'\272H\003\310\001\001'
  _UPDATECLUSTERREQUEST.fields_by_name['metadata']._options = None
  _UPDATECLUSTERREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _STOPCLUSTERREQUEST.fields_by_name['id']._options = None
  _STOPCLUSTERREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _STARTCLUSTERREQUEST.fields_by_name['id']._options = None
  _STARTCLUSTERREQUEST.fields_by_name['id']._serialized_options = b'\272H\003\310\001\001'
  _CLUSTERSERVICE._options = None
  _CLUSTERSERVICE._serialized_options = b'\272J\016postgresql.msp'
  _globals['_GETCLUSTERREQUEST']._serialized_start=295
  _globals['_GETCLUSTERREQUEST']._serialized_end=338
  _globals['_GETCLUSTERFORBACKUPREQUEST']._serialized_start=340
  _globals['_GETCLUSTERFORBACKUPREQUEST']._serialized_end=429
  _globals['_LISTCLUSTERSREQUEST']._serialized_start=431
  _globals['_LISTCLUSTERSREQUEST']._serialized_end=549
  _globals['_LISTCLUSTERSRESPONSE']._serialized_start=552
  _globals['_LISTCLUSTERSRESPONSE']._serialized_end=683
  _globals['_CREATECLUSTERREQUEST']._serialized_start=686
  _globals['_CREATECLUSTERREQUEST']._serialized_end=853
  _globals['_RESTORECLUSTERREQUEST']._serialized_start=856
  _globals['_RESTORECLUSTERREQUEST']._serialized_end=1178
  _globals['_DELETECLUSTERREQUEST']._serialized_start=1180
  _globals['_DELETECLUSTERREQUEST']._serialized_end=1218
  _globals['_UPDATECLUSTERREQUEST']._serialized_start=1221
  _globals['_UPDATECLUSTERREQUEST']._serialized_end=1380
  _globals['_STOPCLUSTERREQUEST']._serialized_start=1382
  _globals['_STOPCLUSTERREQUEST']._serialized_end=1426
  _globals['_STARTCLUSTERREQUEST']._serialized_start=1428
  _globals['_STARTCLUSTERREQUEST']._serialized_end=1473
  _globals['_CLUSTERSERVICE']._serialized_start=1476
  _globals['_CLUSTERSERVICE']._serialized_end=2522
# @@protoc_insertion_point(module_scope)



# type: ignore
import logging

import pytest


@pytest.mark.asyncio
async def test_credentials_updater() -> None:
    from asyncio import sleep

    import grpc
    import grpc.aio
    from cryptography.hazmat.primitives.asymmetric import rsa

    # Imports needed inside the test function
    from grpc.aio._metadata import Metadata

    import nebius.api.nebius.common.v1.operation_pb2 as operation_pb2
    import nebius.api.nebius.compute.v1.disk_pb2 as disk_pb2
    from nebius.aio.channel import Channel
    from nebius.api.nebius.compute.v1.disk_service_pb2 import (
        GetDiskRequest,
        UpdateDiskRequest,
    )
    from nebius.api.nebius.compute.v1.disk_service_pb2_grpc import (
        DiskServiceServicer,
        add_DiskServiceServicer_to_server,
    )
    from nebius.api.nebius.iam.v1.token_exchange_service_pb2_grpc import (
        TokenExchangeService,
        add_TokenExchangeServiceServicer_to_server,
    )
    from nebius.api.nebius.iam.v1.token_service_pb2 import (
        CreateTokenResponse,
        ExchangeTokenRequest,
    )
    from nebius.base.options import INSECURE
    from nebius.base.service_account.service_account import ServiceAccount

    stub_key = rsa.generate_private_key(
        public_exponent=65537,
        key_size=1024,
    )

    # Set up logging
    logging.basicConfig(level=logging.DEBUG)

    call = 0

    class MockTokenExchangeService(TokenExchangeService):
        async def Exchange(  # noqa: N802 — GRPC method
            self,
            request: ExchangeTokenRequest,
            context: grpc.aio.ServicerContext[GetDiskRequest, disk_pb2.Disk],
        ) -> CreateTokenResponse:
            nonlocal call
            if call == 0:
                call += 1
                await sleep(6)
            ret = CreateTokenResponse(
                access_token="foo-bar",
                expires_in=3600,
                issued_token_type="Bearer",
                token_type="Bearer",
            )
            return ret

    # Define a mock server class
    class MockInstanceService(DiskServiceServicer):
        async def Update(  # noqa: N802 — GRPC method
            self,
            request: UpdateDiskRequest,
            context: grpc.aio.ServicerContext[GetDiskRequest, disk_pb2.Disk],
        ) -> operation_pb2.Operation:
            assert request.metadata.id == "foo-bar"
            md = context.invocation_metadata()
            assert md is not None
            # Recreate metadata for ease of checking
            md = Metadata(*[v for v in md])
            assert md.get("x-idempotency-key", "") != ""

            await context.send_initial_metadata(
                (
                    ("x-request-id", "some-req-id"),
                    ("x-trace-id", "some-trace-id"),
                )
            )

            ret = operation_pb2.Operation()
            return ret

    # Randomly assign an IPv6 address and port for the server
    srv = grpc.aio.server()
    assert isinstance(srv, grpc.aio.Server)
    port = srv.add_insecure_port("[::]:0")
    add_DiskServiceServicer_to_server(MockInstanceService(), srv)
    add_TokenExchangeServiceServicer_to_server(MockTokenExchangeService(), srv)
    await srv.start()

    # Use the actual port assigned by the server
    address = f"localhost:{port}"

    channel = None
    try:
        # Set up the client channel
        channel = Channel(
            domain=address,
            options=[(INSECURE, True)],
            credentials=ServiceAccount(
                private_key=stub_key,
                public_key_id="public-key-test",
                service_account_id="service-account-test",
            ),
        )
        from nebius.aio.operation import Operation
        from nebius.api.nebius.compute.v1 import (
            DiskServiceClient,
            GetDiskRequest,
            UpdateDiskRequest,
        )

        client = DiskServiceClient(channel)
        upd = UpdateDiskRequest()
        upd.metadata.id = "foo-bar"
        req = client.update(upd, auth_timeout=10.0)

        # Await response and metadata
        ret = await req
        assert isinstance(ret, Operation)
    finally:
        # Clean up
        if channel is not None:
            await channel.close()
        await srv.stop(0)


@pytest.mark.asyncio
async def test_credentials_updater_sync() -> None:
    from asyncio import sleep

    import grpc
    import grpc.aio
    from cryptography.hazmat.primitives.asymmetric import rsa

    # Imports needed inside the test function
    from grpc.aio._metadata import Metadata

    import nebius.api.nebius.common.v1.operation_pb2 as operation_pb2
    import nebius.api.nebius.compute.v1.disk_pb2 as disk_pb2
    from nebius.aio.channel import Channel
    from nebius.api.nebius.compute.v1.disk_service_pb2 import (
        GetDiskRequest,
        UpdateDiskRequest,
    )
    from nebius.api.nebius.compute.v1.disk_service_pb2_grpc import (
        DiskServiceServicer,
        add_DiskServiceServicer_to_server,
    )
    from nebius.api.nebius.iam.v1.token_exchange_service_pb2_grpc import (
        TokenExchangeService,
        add_TokenExchangeServiceServicer_to_server,
    )
    from nebius.api.nebius.iam.v1.token_service_pb2 import (
        CreateTokenResponse,
        ExchangeTokenRequest,
    )
    from nebius.base.options import INSECURE
    from nebius.base.service_account.service_account import ServiceAccount

    stub_key = rsa.generate_private_key(
        public_exponent=65537,
        key_size=1024,
    )

    # Set up logging
    logging.basicConfig(level=logging.DEBUG)

    call = 0

    class MockTokenExchangeService(TokenExchangeService):
        async def Exchange(  # noqa: N802 — GRPC method
            self,
            request: ExchangeTokenRequest,
            context: grpc.aio.ServicerContext[GetDiskRequest, disk_pb2.Disk],
        ) -> CreateTokenResponse:
            nonlocal call
            if call == 0:
                call += 1
                await sleep(6)
            ret = CreateTokenResponse(
                access_token="foo-bar",
                expires_in=3600,
                issued_token_type="Bearer",
                token_type="Bearer",
            )
            return ret

    # Define a mock server class
    class MockInstanceService(DiskServiceServicer):
        async def Update(  # noqa: N802 — GRPC method
            self,
            request: UpdateDiskRequest,
            context: grpc.aio.ServicerContext[GetDiskRequest, disk_pb2.Disk],
        ) -> operation_pb2.Operation:
            assert request.metadata.id == "foo-bar"
            md = context.invocation_metadata()
            assert md is not None
            # Recreate metadata for ease of checking
            md = Metadata(*[v for v in md])
            assert md.get("x-idempotency-key", "") != ""

            await context.send_initial_metadata(
                (
                    ("x-request-id", "some-req-id"),
                    ("x-trace-id", "some-trace-id"),
                )
            )

            ret = operation_pb2.Operation()
            return ret

    # Randomly assign an IPv6 address and port for the server
    srv = grpc.aio.server()
    assert isinstance(srv, grpc.aio.Server)
    port = srv.add_insecure_port("[::]:0")
    add_DiskServiceServicer_to_server(MockInstanceService(), srv)
    add_TokenExchangeServiceServicer_to_server(MockTokenExchangeService(), srv)
    await srv.start()

    # Use the actual port assigned by the server
    address = f"localhost:{port}"

    channel = None
    try:
        # Set up the client channel
        channel = Channel(
            domain=address,
            options=[(INSECURE, True)],
            credentials=ServiceAccount(
                private_key=stub_key,
                public_key_id="public-key-test",
                service_account_id="service-account-test",
            ),
        )
        from nebius.aio.operation import Operation
        from nebius.aio.token.renewable import (
            OPTION_RENEW_REQUEST_TIMEOUT,
            OPTION_RENEW_REQUIRED,
            OPTION_RENEW_SYNCHRONOUS,
        )
        from nebius.api.nebius.compute.v1 import (
            DiskServiceClient,
            GetDiskRequest,
            UpdateDiskRequest,
        )

        client = DiskServiceClient(channel)
        upd = UpdateDiskRequest()
        upd.metadata.id = "foo-bar"
        req = client.update(
            upd,
            auth_timeout=10.0,
            auth_options={
                OPTION_RENEW_REQUIRED: "1",
                OPTION_RENEW_SYNCHRONOUS: "1",
                OPTION_RENEW_REQUEST_TIMEOUT: ".1",
            },
        )

        # Await response and metadata
        ret = await req
        assert isinstance(ret, Operation)
    finally:
        # Clean up
        if channel is not None:
            await channel.close()
        await srv.stop(0)


@pytest.mark.asyncio
async def test_credentials_updater_sync_error() -> None:
    import grpc
    import grpc.aio
    from cryptography.hazmat.primitives.asymmetric import rsa

    # Imports needed inside the test function
    from grpc.aio._metadata import Metadata

    import nebius.api.nebius.common.v1.operation_pb2 as operation_pb2
    import nebius.api.nebius.compute.v1.disk_pb2 as disk_pb2
    from nebius.aio.channel import Channel
    from nebius.aio.service_error import RequestError, RequestStatusExtended
    from nebius.api.nebius.compute.v1.disk_service_pb2 import (
        GetDiskRequest,
        UpdateDiskRequest,
    )
    from nebius.api.nebius.compute.v1.disk_service_pb2_grpc import (
        DiskServiceServicer,
        add_DiskServiceServicer_to_server,
    )
    from nebius.api.nebius.iam.v1.token_exchange_service_pb2_grpc import (
        TokenExchangeService,
        add_TokenExchangeServiceServicer_to_server,
    )
    from nebius.api.nebius.iam.v1.token_service_pb2 import (
        CreateTokenResponse,
        ExchangeTokenRequest,
    )
    from nebius.base.options import INSECURE
    from nebius.base.service_account.service_account import ServiceAccount

    stub_key = rsa.generate_private_key(
        public_exponent=65537,
        key_size=1024,
    )

    # Set up logging
    logging.basicConfig(level=logging.DEBUG)

    class MockTokenExchangeService(TokenExchangeService):
        async def Exchange(  # noqa: N802 — GRPC method
            self,
            request: ExchangeTokenRequest,
            context: grpc.aio.ServicerContext[GetDiskRequest, disk_pb2.Disk],
        ) -> CreateTokenResponse:
            await context.send_initial_metadata(
                (
                    ("x-request-id", "some-req-id"),
                    ("x-trace-id", "some-trace-id"),
                )
            )

            import nebius.api.nebius.common.v1.error_pb2 as error_pb2
            from nebius.base._service_error import trailing_metadata_of_errors

            quota_violation = error_pb2.QuotaFailure.Violation(
                quota="test_quota",
                message="testing quota failure",
                limit="42",
                requested="69",
            )
            quota_failure = error_pb2.QuotaFailure(violations=[quota_violation])
            service_error = error_pb2.ServiceError(
                service="example.service",
                code="test failure",
                quota_failure=quota_failure,
            )

            await context.abort(
                code=grpc.StatusCode.RESOURCE_EXHAUSTED,
                details="test exhausted",
                trailing_metadata=trailing_metadata_of_errors(
                    service_error,
                    status_code=grpc.StatusCode.RESOURCE_EXHAUSTED.value,
                    status_message="test exhausted",
                ),
            )

    # Define a mock server class
    class MockInstanceService(DiskServiceServicer):
        async def Update(  # noqa: N802 — GRPC method
            self,
            request: UpdateDiskRequest,
            context: grpc.aio.ServicerContext[GetDiskRequest, disk_pb2.Disk],
        ) -> operation_pb2.Operation:
            assert request.metadata.id == "foo-bar"
            md = context.invocation_metadata()
            assert md is not None
            # Recreate metadata for ease of checking
            md = Metadata(*[v for v in md])
            assert md.get("x-idempotency-key", "") != ""

            await context.send_initial_metadata(
                (
                    ("x-request-id", "some-req-id"),
                    ("x-trace-id", "some-trace-id"),
                )
            )

            ret = operation_pb2.Operation()
            return ret

    # Randomly assign an IPv6 address and port for the server
    srv = grpc.aio.server()
    assert isinstance(srv, grpc.aio.Server)
    port = srv.add_insecure_port("[::]:0")
    add_DiskServiceServicer_to_server(MockInstanceService(), srv)
    add_TokenExchangeServiceServicer_to_server(MockTokenExchangeService(), srv)
    await srv.start()

    # Use the actual port assigned by the server
    address = f"localhost:{port}"

    channel = None
    try:
        # Set up the client channel
        channel = Channel(
            domain=address,
            options=[(INSECURE, True)],
            credentials=ServiceAccount(
                private_key=stub_key,
                public_key_id="public-key-test",
                service_account_id="service-account-test",
            ),
        )
        from nebius.aio.token.renewable import (
            OPTION_RENEW_REQUEST_TIMEOUT,
            OPTION_RENEW_REQUIRED,
            OPTION_RENEW_SYNCHRONOUS,
        )
        from nebius.api.nebius.compute.v1 import (
            DiskServiceClient,
            GetDiskRequest,
            UpdateDiskRequest,
        )

        client = DiskServiceClient(channel)
        upd = UpdateDiskRequest()
        upd.metadata.id = "foo-bar"
        req = client.update(
            upd,
            auth_timeout=10.0,
            auth_options={
                OPTION_RENEW_REQUIRED: "1",
                OPTION_RENEW_SYNCHRONOUS: "1",
                OPTION_RENEW_REQUEST_TIMEOUT: ".1",
            },
        )

        # Await response and metadata
        await req
    except RequestError as e:
        assert (
            str(e) == "Request error RESOURCE_EXHAUSTED: test exhausted; "
            "request_id: some-req-id; trace_id: some-trace-id; Caused by error: "
            "1. test failure in service example.service quota failure, violations:"
            "  test_quota 69 of 42: testing quota failure;"
        )
        assert e.status.request_id == "some-req-id"
        assert e.status.trace_id == "some-trace-id"
        assert isinstance(e.status, RequestStatusExtended)
        assert len(e.status.service_errors) == 1
        assert e.status.service_errors[0].quota_failure is not None
    finally:
        # Clean up
        if channel is not None:
            await channel.close()
        await srv.stop(0)



from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class Account(_message.Message):
    __slots__ = ["user_account", "service_account", "anonymous_account"]
    class UserAccount(_message.Message):
        __slots__ = ["id"]
        ID_FIELD_NUMBER: _ClassVar[int]
        id: str
        def __init__(self, id: _Optional[str] = ...) -> None: ...
    class ServiceAccount(_message.Message):
        __slots__ = ["id"]
        ID_FIELD_NUMBER: _ClassVar[int]
        id: str
        def __init__(self, id: _Optional[str] = ...) -> None: ...
    class AnonymousAccount(_message.Message):
        __slots__ = []
        def __init__(self) -> None: ...
    USER_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    SERVICE_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    ANONYMOUS_ACCOUNT_FIELD_NUMBER: _ClassVar[int]
    user_account: Account.UserAccount
    service_account: Account.ServiceAccount
    anonymous_account: Account.AnonymousAccount
    def __init__(self, user_account: _Optional[_Union[Account.UserAccount, _Mapping]] = ..., service_account: _Optional[_Union[Account.ServiceAccount, _Mapping]] = ..., anonymous_account: _Optional[_Union[Account.AnonymousAccount, _Mapping]] = ...) -> None: ...



# type: ignore

import pytest

from nebius.aio import request

request.DEFAULT_AUTH_TIMEOUT = 5.0


def test_load_config_from_home(tmp_path, monkeypatch) -> None:
    from nebius.aio.cli_config import Config

    nebius_dir = tmp_path / ".nebius"
    nebius_dir.mkdir(parents=True, exist_ok=True)

    monkeypatch.setenv("HOME", str(tmp_path))

    with open(nebius_dir / "config.yaml", "w+") as f:
        f.write(
            """
default: prod
profiles:
    prod:
        endpoint: my-endpoint.net
        parent-id: project-e00some-id
"""
        )
    # Load the configuration
    config = Config("foo")
    assert config.parent_id == "project-e00some-id"


@pytest.mark.asyncio
async def test_load_config_env_token(tmp_path, monkeypatch) -> None:
    from asyncio import Future

    from nebius.aio.abc import ClientChannelInterface
    from nebius.aio.cli_config import Config
    from nebius.aio.token.static import EnvBearer

    nebius_dir = tmp_path / ".nebius"
    nebius_dir.mkdir(parents=True, exist_ok=True)

    monkeypatch.setenv("HOME", str(tmp_path))
    monkeypatch.setenv("NEBIUS_IAM_TOKEN", "my-token")

    with open(nebius_dir / "config.yaml", "w+") as f:
        f.write(
            """
default: prod
profiles:
    prod:
        endpoint: my-endpoint.net
        parent-id: project-e00some-id
"""
        )
    # Load the configuration
    config = Config("foo")
    fut = Future[ClientChannelInterface]()
    tok = config.get_credentials(fut)
    assert isinstance(tok, EnvBearer)
    receiver = tok.receiver()
    tok = await receiver.fetch()
    assert tok.token == "my-token"


@pytest.mark.asyncio
async def test_load_config_token_file(tmp_path, monkeypatch) -> None:
    from asyncio import Future

    from nebius.aio.abc import ClientChannelInterface
    from nebius.aio.cli_config import Config
    from nebius.aio.token.file import Bearer as FileBearer

    nebius_dir = tmp_path / ".nebius"
    nebius_dir.mkdir(parents=True, exist_ok=True)

    monkeypatch.setenv("HOME", str(tmp_path))
    monkeypatch.delenv("NEBIUS_IAM_TOKEN", raising=False)

    with open(nebius_dir / "config.yaml", "w+") as f:
        f.write(
            """
default: prod
profiles:
    prod:
        endpoint: my-endpoint.net
        parent-id: project-e00some-id
        token-file: ~/token.txt
"""
        )
    with open(tmp_path / "token.txt", "w+") as f:
        f.write("my-token")
    # Load the configuration
    config = Config("foo")
    fut = Future[ClientChannelInterface]()
    tok = config.get_credentials(fut)
    assert isinstance(tok, FileBearer)
    receiver = tok.receiver()
    tok = await receiver.fetch()
    assert tok.token == "my-token"


@pytest.mark.asyncio
async def test_load_config_no_env(tmp_path, monkeypatch) -> None:
    from asyncio import Future

    from nebius.aio.abc import ClientChannelInterface
    from nebius.aio.cli_config import Config
    from nebius.aio.token.file import Bearer as FileBearer

    nebius_dir = tmp_path / ".nebius"
    nebius_dir.mkdir(parents=True, exist_ok=True)

    monkeypatch.setenv("HOME", str(tmp_path))
    monkeypatch.setenv("NEBIUS_IAM_TOKEN", "wrong-token")

    with open(nebius_dir / "config.yaml", "w+") as f:
        f.write(
            """
default: prod
profiles:
    prod:
        endpoint: my-endpoint.net
        parent-id: project-e00some-id
        token-file: ~/token.txt
"""
        )
    with open(tmp_path / "token.txt", "w+") as f:
        f.write("my-token")
    # Load the configuration
    config = Config("foo", no_env=True)
    fut = Future[ClientChannelInterface]()
    tok = config.get_credentials(fut)
    assert isinstance(tok, FileBearer)
    receiver = tok.receiver()
    tok = await receiver.fetch()
    assert tok.token == "my-token"


def test_load_config_other_profile(tmp_path, monkeypatch) -> None:
    from nebius.aio.cli_config import Config

    nebius_dir = tmp_path / ".nebius"
    nebius_dir.mkdir(parents=True, exist_ok=True)

    monkeypatch.setenv("HOME", str(tmp_path))

    with open(nebius_dir / "config.yaml", "w+") as f:
        f.write(
            """
default: prod
profiles:
    prod:
        endpoint: my-endpoint.net
        parent-id: project-e00some-id
    test:
        endpoint: test-endpoint.net
        parent-id: project-e00test-id
"""
        )
    # Load the configuration
    config = Config("foo", profile="test")
    assert config.parent_id == "project-e00test-id"


def test_load_config_no_project(tmp_path, monkeypatch) -> None:
    from nebius.aio.cli_config import Config

    nebius_dir = tmp_path / ".nebius"
    nebius_dir.mkdir(parents=True, exist_ok=True)

    monkeypatch.setenv("HOME", str(tmp_path))

    with open(nebius_dir / "config.yaml", "w+") as f:
        f.write(
            """
default: prod
profiles:
    prod:
        endpoint: my-endpoint.net
"""
        )
    # Load the configuration
    config = Config("foo")
    try:
        config.parent_id
    except Exception as e:
        assert str(e) == "Missing parent-id in the profile."


def test_load_config_from_home_fail(tmp_path, monkeypatch) -> None:
    from nebius.aio.cli_config import Config

    nebius_dir = tmp_path / ".nebius"
    nebius_dir.mkdir(parents=True, exist_ok=True)

    monkeypatch.setenv("HOME", str(tmp_path))

    try:
        Config("foo")
    except FileNotFoundError as e:
        assert str(e).startswith("Config file ")
        assert str(e).endswith("/.nebius/config.yaml not found.")


def test_load_config_from_other_place(tmp_path, monkeypatch) -> None:
    from nebius.aio.cli_config import Config

    nebius_dir = tmp_path / "home/.nebius"
    nebius_dir.mkdir(parents=True, exist_ok=True)
    tmp_file = tmp_path / "config.yaml"

    monkeypatch.setenv("HOME", str(tmp_path / "home"))

    with open(tmp_file, "w+") as f:
        f.write(
            """
default: prod
profiles:
    prod:
        endpoint: my-endpoint.net
        parent-id: project-e00some-id
"""
        )
    # Load the configuration
    config = Config("foo", config_file=str(tmp_file))
    assert config.parent_id == "project-e00some-id"


def test_load_config_federated_subject_file(tmp_path, monkeypatch) -> None:
    from nebius.aio.cli_config import Config
    from nebius.aio.token.federated_credentials import FederatedCredentialsBearer

    nebius_dir = tmp_path / ".nebius"
    nebius_dir.mkdir(parents=True, exist_ok=True)

    monkeypatch.setenv("HOME", str(tmp_path))

    actor_file = tmp_path / "actor.txt"
    actor_file.write_text("actor-token")

    with open(nebius_dir / "config.yaml", "w+") as f:
        f.write(
            f"""
default: prod
profiles:
    prod:
        endpoint: my-endpoint.net
        parent-id: project-e00some-id
        auth-type: service account
        service-account-id: sa-actor
        federated-subject-credentials-file-path: {actor_file}
"""
        )

    from asyncio import Future

    from nebius.aio.abc import ClientChannelInterface

    config = Config("foo")
    fut = Future[ClientChannelInterface]()
    cred = config.get_credentials(fut)
    assert isinstance(cred, FederatedCredentialsBearer)


def test_load_config_service_account_credentials_file(tmp_path, monkeypatch) -> None:
    # create a service account credentials JSON with a PEM private key
    from cryptography.hazmat.primitives import serialization
    from cryptography.hazmat.primitives.asymmetric import rsa

    from nebius.aio.cli_config import Config
    from nebius.aio.token.service_account import ServiceAccountBearer

    nebius_dir = tmp_path / ".nebius"
    nebius_dir.mkdir(parents=True, exist_ok=True)

    monkeypatch.setenv("HOME", str(tmp_path))

    # generate key
    key = rsa.generate_private_key(public_exponent=65537, key_size=2048)
    pem = key.private_bytes(
        encoding=serialization.Encoding.PEM,
        format=serialization.PrivateFormat.PKCS8,
        encryption_algorithm=serialization.NoEncryption(),
    ).decode("utf-8")

    import json

    cred_file = tmp_path / "sa_creds.json"
    cred_file.write_text(
        json.dumps(
            {
                "subject-credentials": {
                    "type": "JWT",
                    "alg": "RS256",
                    "private-key": pem,
                    "kid": "kid-1",
                    "iss": "sa-creds",
                    "sub": "sa-creds",
                }
            }
        )
    )

    with open(nebius_dir / "config.yaml", "w+") as f:
        f.write(
            f"""
default: prod
profiles:
    prod:
        endpoint: my-endpoint.net
        parent-id: project-e00some-id
        auth-type: service account
        service-account-credentials-file-path: {cred_file}
"""
        )

    from asyncio import Future

    from nebius.aio.abc import ClientChannelInterface

    config = Config("foo")
    fut = Future[ClientChannelInterface]()
    cred = config.get_credentials(fut)
    assert isinstance(cred, ServiceAccountBearer)


def test_load_config_private_key_file(tmp_path, monkeypatch) -> None:
    # Test private-key-file-path
    from cryptography.hazmat.primitives import serialization
    from cryptography.hazmat.primitives.asymmetric import rsa

    from nebius.aio.cli_config import Config
    from nebius.aio.token.service_account import ServiceAccountBearer

    nebius_dir = tmp_path / ".nebius"
    nebius_dir.mkdir(parents=True, exist_ok=True)

    monkeypatch.setenv("HOME", str(tmp_path))

    # generate key
    key = rsa.generate_private_key(public_exponent=65537, key_size=2048)
    pem = key.private_bytes(
        encoding=serialization.Encoding.PEM,
        format=serialization.PrivateFormat.PKCS8,
        encryption_algorithm=serialization.NoEncryption(),
    ).decode("utf-8")

    pem_file = tmp_path / "pk.pem"
    pem_file.write_text(pem)

    # first test private-key-file-path
    with open(nebius_dir / "config.yaml", "w+") as f:
        f.write(
            f"""
default: prod
profiles:
    prod:
        endpoint: my-endpoint.net
        parent-id: project-e00some-id
        auth-type: service account
        service-account-id: sa-file
        public-key-id: kid-file
        private-key-file-path: {pem_file}
"""
        )
    config = Config("foo")
    from asyncio import Future

    from nebius.aio.abc import ClientChannelInterface

    fut = Future[ClientChannelInterface]()
    cred = config.get_credentials(fut)
    assert isinstance(cred, ServiceAccountBearer)


def test_load_config_private_key_inline(tmp_path, monkeypatch) -> None:
    # Test inline private-key branch
    from cryptography.hazmat.primitives import serialization
    from cryptography.hazmat.primitives.asymmetric import rsa

    from nebius.aio.cli_config import Config
    from nebius.aio.token.service_account import ServiceAccountBearer

    nebius_dir = tmp_path / ".nebius"
    nebius_dir.mkdir(parents=True, exist_ok=True)

    monkeypatch.setenv("HOME", str(tmp_path))

    # generate key
    key = rsa.generate_private_key(public_exponent=65537, key_size=2048)
    pem = key.private_bytes(
        encoding=serialization.Encoding.PEM,
        format=serialization.PrivateFormat.PKCS8,
        encryption_algorithm=serialization.NoEncryption(),
    ).decode("utf-8")

    pem_file = tmp_path / "pk.pem"
    pem_file.write_text(pem)
    # now inline private-key
    with open(nebius_dir / "config.yaml", "w+") as f:
        # indent PEM as YAML literal
        pem_block = "\n".join(["            " + line for line in pem.splitlines()])
        f.write(
            """
default: prod
profiles:
    prod:
        endpoint: my-endpoint.net
        parent-id: project-e00some-id
        auth-type: service account
        service-account-id: sa-inline
        public-key-id: kid-inline
        private-key: |
"""
            + pem_block
        )
    config = Config("foo")
    from asyncio import Future

    from nebius.aio.abc import ClientChannelInterface

    fut = Future[ClientChannelInterface]()
    cred = config.get_credentials(fut)
    assert isinstance(cred, ServiceAccountBearer)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: nebius/msp/serverless/v1alpha1/endpoint_service.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from nebius.api.buf.validate import validate_pb2 as buf_dot_validate_dot_validate__pb2
from nebius.api.nebius import annotations_pb2 as nebius_dot_annotations__pb2
from nebius.api.nebius.common.v1 import metadata_pb2 as nebius_dot_common_dot_v1_dot_metadata__pb2
from nebius.api.nebius.common.v1 import operation_pb2 as nebius_dot_common_dot_v1_dot_operation__pb2
from nebius.api.nebius.msp.serverless.v1alpha1 import endpoint_pb2 as nebius_dot_msp_dot_serverless_dot_v1alpha1_dot_endpoint__pb2
from nebius.api.nebius.msp.v1alpha1 import common_pb2 as nebius_dot_msp_dot_v1alpha1_dot_common__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n5nebius/msp/serverless/v1alpha1/endpoint_service.proto\x12\x1enebius.msp.serverless.v1alpha1\x1a\x1b\x62uf/validate/validate.proto\x1a\x18nebius/annotations.proto\x1a\x1fnebius/common/v1/metadata.proto\x1a nebius/common/v1/operation.proto\x1a-nebius/msp/serverless/v1alpha1/endpoint.proto\x1a nebius/msp/v1alpha1/common.proto\"\xc2\x01\n\x15\x43reateEndpointRequest\x12\x46\n\x08metadata\x18\x01 \x01(\x0b\x32\".nebius.common.v1.ResourceMetadataB\x06\xbaH\x03\xc8\x01\x01R\x08metadata\x12H\n\x04spec\x18\x02 \x01(\x0b\x32,.nebius.msp.serverless.v1alpha1.EndpointSpecB\x06\xbaH\x03\xc8\x01\x01R\x04spec\x12\x17\n\x07\x64ry_run\x18\x03 \x01(\x08R\x06\x64ryRun\"\x7f\n\x15ListEndpointsResponse\x12>\n\x05items\x18\x01 \x03(\x0b\x32(.nebius.msp.serverless.v1alpha1.EndpointR\x05items\x12&\n\x0fnext_page_token\x18\x02 \x01(\tR\rnextPageToken2\xe8\x04\n\x0f\x45ndpointService\x12P\n\x03Get\x12\x1f.nebius.msp.v1alpha1.GetRequest\x1a(.nebius.msp.serverless.v1alpha1.Endpoint\x12\\\n\tGetByName\x12%.nebius.msp.v1alpha1.GetByNameRequest\x1a(.nebius.msp.serverless.v1alpha1.Endpoint\x12_\n\x04List\x12 .nebius.msp.v1alpha1.ListRequest\x1a\x35.nebius.msp.serverless.v1alpha1.ListEndpointsResponse\x12\\\n\x06\x43reate\x12\x35.nebius.msp.serverless.v1alpha1.CreateEndpointRequest\x1a\x1b.nebius.common.v1.Operation\x12I\n\x06\x44\x65lete\x12\".nebius.msp.v1alpha1.DeleteRequest\x1a\x1b.nebius.common.v1.Operation\x12G\n\x05Start\x12!.nebius.msp.v1alpha1.StartRequest\x1a\x1b.nebius.common.v1.Operation\x12\x45\n\x04Stop\x12 .nebius.msp.v1alpha1.StopRequest\x1a\x1b.nebius.common.v1.Operation\x1a\x0b\xbaJ\x08\x61pps.mspB}\n%ai.nebius.pub.msp.serverless.v1alpha1B\x14\x45ndpointServiceProtoP\x01Z<github.com/nebius/gosdk/proto/nebius/msp/serverless/v1alpha1b\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'nebius.msp.serverless.v1alpha1.endpoint_service_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'\n%ai.nebius.pub.msp.serverless.v1alpha1B\024EndpointServiceProtoP\001Z<github.com/nebius/gosdk/proto/nebius/msp/serverless/v1alpha1'
  _CREATEENDPOINTREQUEST.fields_by_name['metadata']._options = None
  _CREATEENDPOINTREQUEST.fields_by_name['metadata']._serialized_options = b'\272H\003\310\001\001'
  _CREATEENDPOINTREQUEST.fields_by_name['spec']._options = None
  _CREATEENDPOINTREQUEST.fields_by_name['spec']._serialized_options = b'\272H\003\310\001\001'
  _ENDPOINTSERVICE._options = None
  _ENDPOINTSERVICE._serialized_options = b'\272J\010apps.msp'
  _globals['_CREATEENDPOINTREQUEST']._serialized_start=293
  _globals['_CREATEENDPOINTREQUEST']._serialized_end=487
  _globals['_LISTENDPOINTSRESPONSE']._serialized_start=489
  _globals['_LISTENDPOINTSRESPONSE']._serialized_end=616
  _globals['_ENDPOINTSERVICE']._serialized_start=619
  _globals['_ENDPOINTSERVICE']._serialized_end=1235
# @@protoc_insertion_point(module_scope)



"""File-backed bearer helpers.

This module adapts :class:`ThrottledTokenCache` into the Bearer/Receiver
abstractions used by the SDK. It provides lightweight types intended for
simple file-backed credential lookups.

Types
-----

- :class:`PureFileCacheReceiver` -- A :class:`nebius.aio.token.token.Receiver`
    implementation that reads a token from a :class:`ThrottledTokenCache`.
    It does not perform retries; the cache layer implements throttling and
    robustness.
- :class:`PureFileCacheBearer` -- A :class:`nebius.aio.token.token.Bearer` that
    constructs a :class:`ThrottledTokenCache` for a named credential and
    returns a :class:`PureFileCacheReceiver` when requested.

Example
-------

Create a bearer that reads credentials from the default credentials file
and caches them for five minutes::

    from nebius.aio.token.file_cache.file_bearer import PureFileCacheBearer
    from nebius.sdk import SDK

    bearer = PureFileCacheBearer('my-service')
    sdk = SDK(credentials=bearer)

"""

from datetime import timedelta
from logging import getLogger
from pathlib import Path

from nebius.aio.token.token import Bearer as ParentBearer
from nebius.aio.token.token import Receiver as ParentReceiver
from nebius.aio.token.token import Token
from nebius.base.constants import DEFAULT_CONFIG_DIR, DEFAULT_CREDENTIALS_FILE

from .throttled_token_cache import ThrottledTokenCache

log = getLogger(__name__)


class PureFileCacheReceiver(ParentReceiver):
    """Receiver that reads tokens from a :class:`ThrottledTokenCache`.

    Behavior
    --------
    - ``_fetch`` returns the token stored in the cache or
      :meth:`nebius.aio.token.token.Token.empty` when no token exists.
    - ``can_retry`` returns ``False``; callers should not apply transport
      retries to a local file cache.

    :param cache: Throttled token cache implementation.
    """

    def __init__(self, cache: ThrottledTokenCache) -> None:
        """Create a receiver backed by ``cache``.

        No file I/O occurs during construction; the cache performs I/O on demand.
        """
        super().__init__()
        self._cache = cache

    async def _fetch(
        self, timeout: float | None = None, options: dict[str, str] | None = None
    ) -> Token:
        """Return the cached token or an empty token.

        :param timeout: Ignored. Present for interface compatibility.
        :param options: Unused by this receiver.
        :returns: Token from the underlying cache or an empty token.

        """
        return await self._cache.get() or Token.empty()

    def can_retry(
        self,
        err: Exception,
        options: dict[str, str] | None = None,
    ) -> bool:
        """Return `False` to indicate no retries should be attempted.

        :param err: The exception raised during a prior fetch attempt.
        :param options: Optional receiver options (unused).
        :returns: Always `False`.
        """
        return False


class PureFileCacheBearer(ParentBearer):
    """Bearer that exposes a :class:`PureFileCacheReceiver` for a named
    token.

    Notes
    -----

    Construction is inexpensive; the cache performs I/O lazily when
    tokens are accessed via the receiver.

    :param name: Logical name for the credential.
    :param cache_file: Destination YAML file used to persist tokens.
    :param throttle: Throttle interval for in-memory caching.

    Example
    -------

    Create a bearer that reads credentials from the default credentials file
    and caches them for five minutes::

        from nebius.aio.token.file_cache.file_bearer import PureFileCacheBearer
        from nebius.sdk import SDK

        bearer = PureFileCacheBearer('my-service')
        sdk = SDK(credentials=bearer)
    """

    def __init__(
        self,
        name: str,
        cache_file: str | Path = Path(DEFAULT_CONFIG_DIR) / DEFAULT_CREDENTIALS_FILE,
        throttle: timedelta | float = timedelta(minutes=5),
    ) -> None:
        """Create a bearer backed by a throttled file cache."""
        self._name = name
        self._cache = ThrottledTokenCache(
            name=self._name, cache_file=cache_file, throttle=throttle
        )

    @property
    def name(self) -> str:
        """Return the logical name for this bearer.

        :returns: The name provided at construction.
        """
        return self._name

    def receiver(self) -> ParentReceiver:
        """Return a :class:`PureFileCacheReceiver` bound to the cache.

        Each call returns a fresh receiver that references the same
        :class:`ThrottledTokenCache` instance.

        :returns: A receiver that reads from the shared cache.
        """
        return PureFileCacheReceiver(self._cache)
